package com.ventas.database;

import java.text.NumberFormat;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;

public class ArticuloDBAdapter {
	public static final String CODIARTI = "_id"; //Cdigo de artculo
    public static final String DESCARTI = "descarti"; //Nombre de artculo
    public static final String CODIUNID = "codiunid"; //Cdigo de unidad de venta
    public static final String PRECTARI = "prectari"; //Precio tarifa
    public static final String PRECMINI = "precmini"; //Precio mnimo

    public static final String DATABASE_TABLE = "articulo"; 
 
    private SQLiteDatabase mDb; 
 
    /** 
     * Constructor - takes the context to allow the database to be 
     * opened/created 
     *  
     * @param ctx 
     *            the Context within which to work 
     */ 
    public ArticuloDBAdapter(SQLiteDatabase db) { 
        this.mDb = db; 
    } 
 
    /** 
     * Create a new articulo. If the articulo is successfully created return the new 
     * rowId for that articulo, otherwise return a -1 to indicate failure. 
     *  
     * @param codiarti 
     * @param descarti 
     * @param codiunid 
     * @param prectari 
     * @param precmini 
     * @return rowId or -1 if failed 
     */ 
    public long create(String codiarti, String descarti, String codiunid, double prectari, double precmini){ 
        ContentValues initialValues = new ContentValues(); 
        initialValues.put(CODIARTI, codiarti); 
        initialValues.put(DESCARTI, descarti); 
        initialValues.put(CODIUNID, codiunid); 
        initialValues.put(PRECTARI, prectari); 
        initialValues.put(PRECMINI, precmini); 
        return this.mDb.insert(DATABASE_TABLE, null, initialValues); 
    } 
 
    /** 
     * Delete the articulo with the given rowId 
     *  
     * @param codiarti 
     * @return true if deleted, false otherwise 
     */ 
    public boolean delete(String codiarti) { 
 
        return this.mDb.delete(DATABASE_TABLE, CODIARTI + "= '" + codiarti + "'", null) > 0; 
    } 
 
    /** 
     * Return a Cursor over the list of all articulos in the database 
     *  
     * @return Cursor over all articulos 
     */ 
    public Cursor getAll() { 
 
        return this.mDb.query(DATABASE_TABLE, new String[] { CODIARTI, 
        		DESCARTI, CODIUNID, PRECTARI, PRECMINI }, null, null, null, null, null); 
    } 
 
    /** 
     * Return a Cursor over the list of all articulos in the database 
     *  
     * @return Cursor over all articulos
     */ 
    public Cursor getAllConditional(String where) throws SQLException {
    	//Si la condicin est vaca, consultar sin condicin ya que ser ms rpido.
    	if (where == null || where.equals("")) {
    		return this.getAll();
    	}

    	try{
   	
	        //Si la condicin no es un cdigo, consultar sobre la descripcion
	    	return this.mDb.query(DATABASE_TABLE, new String[] { CODIARTI, 
	        		DESCARTI, CODIUNID, PRECTARI, PRECMINI}, DESCARTI + " like '%" + where+"%' or " + CODIARTI  + " like '%" + where+"%'",
	        		null, null, null, DESCARTI);
    	}
    	catch (SQLException e){
    		throw e;
    	}
    } 

    /** 
     * Return a Cursor positioned at the articulo that matches the given rowId 
     * @param codiarti 
     * @return Cursor positioned to matching articulo, if found 
     * @throws SQLException if articulo could not be found/retrieved 
     */ 
    public Cursor get(String codiarti) throws SQLException { 
 
        Cursor mCursor = 
 
        this.mDb.query(true, DATABASE_TABLE, new String[] { CODIARTI, 
        		DESCARTI, CODIUNID, PRECTARI, PRECMINI}, CODIARTI + "= '" + codiarti + "'", null, null, null, null, null); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 
 

    /** 
     * Update the articulo. 
     *  
     * @param codiarti 
     * @param descarti 
     * @param codiunid 
     * @param prectari 
     * @param precmini 
     * @return true if the note was successfully updated, false otherwise 
     */ 
    public boolean update(String codiarti, String descarti, String codiunid, double prectari, double precmini){ 
        ContentValues args = new ContentValues(); 
        args.put(CODIARTI, codiarti); 
        args.put(DESCARTI, descarti); 
        args.put(CODIUNID, codiunid); 
        args.put(PRECTARI, prectari); 
        args.put(PRECMINI, precmini); 
 
        return this.mDb.update(DATABASE_TABLE, args, CODIARTI + "= '" + codiarti + "'", null) >0;  
    } 

    /** 
     * Create a new articulo from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public long createFromString(String[] linea){
    	NumberFormat nf = NumberFormat.getInstance();
    	double prectari = 0;
    	double precmini = 0;
    	
    	String codiarti = linea[1];
    	String descarti = linea[2];
    	String codiunid = linea[3];
    	try{
	    	prectari = nf.parse(linea[4]).doubleValue();
    	}catch(Exception e){
       	}
    	
    	try{
	    	precmini = nf.parse(linea[5]).doubleValue();
    	}catch(Exception e){
    	}
    	
    	return create(codiarti, descarti, codiunid, prectari, precmini);
    }

    /** 
     * Update an articulo from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public boolean updateFromString(String[] linea){
    	
    	NumberFormat nf = NumberFormat.getInstance();
    	ContentValues args = new ContentValues(); 
    	double valor = 0;
    	
    	String codiarti = linea[1];
    	args.put(CODIARTI, codiarti); 
    	
    	for (int i=2; i < (linea.length - 1); i = i+2) {
    		
    		if ( linea[i].equalsIgnoreCase(PRECTARI) ||
    			linea[i].equalsIgnoreCase(PRECMINI) ) { //es campo DOUBLE
    			try{
    				valor = nf.parse( linea[i+1] ).doubleValue();
    			}catch(Exception e){
    	       	}
    			args.put(linea[i], valor); 
    		}
    		else { //es campo string
    			args.put(linea[i], linea[i+1]); 
    		}
    		
    	}
    	return this.mDb.update(DATABASE_TABLE, args, CODIARTI + "='" + codiarti + "'", null) >0;  
    	
    }

    /** 
     * Delete articulo from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public void deleteFromString(String[] linea){
    	for (int i=1; i<linea.length; i++){
    		delete(linea[i]);
    	}
    }
}
