package com.ventas.database;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;

public class ConfigDBAdapter {
    public static final String DATABASE_TABLE = "config"; 

    public static final String CODICON = "_id"; 
    public static final String IP_DESTINO = "ip_destino";
    public static final String NOM_TERMINAL = "nom_terminal"; 
    public static final String ID_TERMINAL = "id_terminal"; 
    public static final String ID_EMPRESA = "id_empresa"; 

    private SQLiteDatabase mDb; 
    
    /** 
     * Constructor - takes the SQLiteDatabase to access to the database
     *  
     * @param db 
     *            the SQLiteDatabase within which to work 
     */ 
    public ConfigDBAdapter(SQLiteDatabase db) { 
        this.mDb = db; 
    } 
    
    /** 
     * Create a new config. If the config is successfully created return the new 
     * rowId for that config, otherwise return a -1 to indicate failure. 
     *  
     * @param id 
     * @param ip_destino 
     * @param nombre terminal 
     * @param id terminal 
     * @return rowId or -1 if failed 
     */ 
    public long create(int id, 
    		                  String ip_destino, 
    		                  String nom_terminal, 
    		                  int id_terminal,
    		                  int id_empresa){ 
        ContentValues initialValues = new ContentValues(); 
        initialValues.put(CODICON, id); 
        initialValues.put(IP_DESTINO, ip_destino); 
        initialValues.put(NOM_TERMINAL, nom_terminal); 
        initialValues.put(ID_TERMINAL, id_terminal); 
        initialValues.put(ID_EMPRESA, id_empresa);
        
        return this.mDb.insert(DATABASE_TABLE, null, initialValues); 
    } 
    
    /** 
     * Create a new config. If the config is successfully created return the new 
     * rowId for that config, otherwise return a -1 to indicate failure. 
     *  
     * @param ip_destino 
     * @param nombre terminal 
     * @param id terminal 
     * @return rowId or -1 if failed 
     */ 
    public long create(String ip_destino, 
    		           String nom_terminal, 
    		           int id_terminal,
		               int id_empresa){ 
        ContentValues initialValues = new ContentValues(); 
        initialValues.put(IP_DESTINO, ip_destino); 
        initialValues.put(NOM_TERMINAL, nom_terminal); 
        initialValues.put(ID_TERMINAL, id_terminal); 
        initialValues.put(ID_EMPRESA, id_empresa);
        
        return this.mDb.insert(DATABASE_TABLE, null, initialValues); 
    } 
    
    /** 
     * Delete the config with the given rowId 
     *  
     * @param id 
     * @return true if deleted, false otherwise 
     */ 
    public boolean delete(int id) { 
 
        return this.mDb.delete(DATABASE_TABLE, CODICON + "=" + id, null) > 0; 
    } 
 
    /** 
     * Return a Cursor over the list of all config in the database 
     *  
     * @return Cursor over all config
     */ 
    public Cursor getAll() { 
    	Cursor mCursor =  
    	this.mDb.query(DATABASE_TABLE, new String[] { CODICON, 
    			IP_DESTINO, NOM_TERMINAL, ID_TERMINAL, ID_EMPRESA }, null, null, null, null, null);
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 
    
    /** 
     * Update the config. 
     *  
     * @param id 
     * @param ip_destino 
     * @param nombre terminal 
     * @param id terminal 
     * @return true if the note was successfully updated, false otherwise 
     */ 
    public boolean update(int id, 
				            String ip_destino, 
				            String nom_terminal, 
				            int id_terminal,
				            int id_empresa){ 
        ContentValues args = new ContentValues(); 
        args.put(CODICON, id); 
        args.put(IP_DESTINO, ip_destino); 
        args.put(NOM_TERMINAL, nom_terminal); 
        args.put(ID_TERMINAL, id_terminal); 
        args.put(ID_EMPRESA, id_empresa);
        return this.mDb.update(DATABASE_TABLE, args, CODICON + "=" + id, null) >0;  
    } 
}
