package com.ventas.database;

import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;

public class DBAdapter {

    public static final String DATABASE_NAME = "ventas.db"; 
 
    public static final int DATABASE_VERSION = 1; 
 
    private static final String CREATE_TABLE_CONFIG = 
  	       "create table config (" + ConfigDBAdapter.CODICON + " INTEGER primary key, "  
  	       							+ ConfigDBAdapter.IP_DESTINO + " TEXT,"
  	       							+ ConfigDBAdapter.NOM_TERMINAL + " TEXT,"
  	       							+ ConfigDBAdapter.ID_TERMINAL + " INTEGER,"
     								+ ConfigDBAdapter.ID_EMPRESA + " INTEGER);";
 	       			
    private static final String CREATE_TABLE_ARTICULO = 
    	       "create table articulo (" + ArticuloDBAdapter.CODIARTI + " TEXT primary key, " 
			    						 + ArticuloDBAdapter.DESCARTI+ " TEXT,"
			    	   					 + ArticuloDBAdapter.CODIUNID+ " TEXT,"
			    	   					 + ArticuloDBAdapter.PRECTARI+ " REAL,"
			    	    		   		 + ArticuloDBAdapter.PRECMINI+ " REAL);"; 
    	 
    private static final String CREATE_TABLE_CLIENTE = 
    	       "create table cliente (" + ClienteDBAdapter.CODICLIE + " INTEGER primary key, " 
			    				  	    + ClienteDBAdapter.DESCRIPCION+ " TEXT,"
			    	   					+ ClienteDBAdapter.TITULAR+ " TEXT,"
			    	   					+ ClienteDBAdapter.CODIPROV+ " TEXT,"
			    	    		   		+ ClienteDBAdapter.CODPOSTAL+ " TEXT,"
			    	    		   		+ ClienteDBAdapter.POBLACION+ " TEXT,"
			    	    		   		+ ClienteDBAdapter.DIRECCION+ " TEXT,"
			    	    		   		+ ClienteDBAdapter.TELEFONO1+ " TEXT,"
			    	    		   		+ ClienteDBAdapter.TELEFONO2+ " TEXT);"; 
    	 
    private static final String CREATE_TABLE_PROVINCI = 
  	       "create table provinci (" + ProvinciDBAdapter.CODIPROV + " TEXT primary key, " 
  	    		   					 + ProvinciDBAdapter.DESCRIPCION+ " TEXT);"; 
 	
    private static final String CREATE_TABLE_FMENCLI = 
  	       "create table f_mencli (" + FmencliDBAdapter.CODIMCLI + " TEXT primary key, " 
  	    		   					 + FmencliDBAdapter.DESCMCLI+ " TEXT);"; 
 	
    private static final String CREATE_TABLE_FCLI = 
  	       "create table f_cli (" + FcliDBAdapter.CODICLIE + " INTEGER primary key, " 
 			    				  + FcliDBAdapter.CODIINCI+ " TEXT,"
 			    				  + FcliDBAdapter.CODIMCLI+ " TEXT,"
 			    				  + FcliDBAdapter.CODICOME+ " TEXT,"
 			    				  + FcliDBAdapter.OBSERVACION1+ " TEXT,"
 			    				  + FcliDBAdapter.OBSERVACION2+ " TEXT,"
 			    				  + FcliDBAdapter.CODIINCITMP+ " TEXT);"; 
  	 
    private static final String CREATE_TABLE_FINCI = 
  	       "create table f_inci (" + FinciDBAdapter.CODIINCI + " TEXT primary key, " 
 			    				   + FinciDBAdapter.DESCINCI+ " TEXT,"
 			    				   + FinciDBAdapter.GRABA+ " TEXT,"
 			    				   + FinciDBAdapter.FGRABA+ " TEXT);"; 
  	 
    private static final String CREATE_TABLE_FCOMERC = 
 	       "create table f_comerc (" + FcomercDBAdapter.CODICOME + " TEXT primary key, " 
 	    		   					 + FcomercDBAdapter.DESCCOME+ " TEXT);"; 
	
    private static final String CREATE_TABLE_FMENART = 
 	       "create table f_menart (" + FmenartDBAdapter.CODIMART + " TEXT primary key, " 
 	    		   					 + FmenartDBAdapter.DESCMART+ " TEXT);"; 
	
    private static final String CREATE_TABLE_FCLOFER = 
  	       "create table f_clofer (" + FcloferDBAdapter.CODICOFER + " INTEGER primary key, " 
 			    				     + FcloferDBAdapter.CODICLIE+ " INTEGER,"
 			    	   				 + FcloferDBAdapter.CODIARTI+ " TEXT,"
 			    	   				 + FcloferDBAdapter.FECHDESD+ " TEXT,"
 			    	    		   	 + FcloferDBAdapter.FECHHAST+ " TEXT,"
 			    	    		   	 + FcloferDBAdapter.PRECCOFE+ " REAL,"
 			    	    		   	 + FcloferDBAdapter.COMISION+ " REAL,"
 			    	    		   	 + FcloferDBAdapter.CANTDESC+ " REAL,"
 			    	    		   	 + FcloferDBAdapter.CANTREGAL+ " REAL,"
 			    	    		   	 + FcloferDBAdapter.CODIARRE+ " TEXT);"; 

    private static final String CREATE_TABLE_FCLESP = 
   	       "create table f_clesp (" + FclespDBAdapter.CODICLES + " INTEGER primary key, " 
  			    				    + FclespDBAdapter.CODICLIE+ " INTEGER,"
  			    	   				+ FclespDBAdapter.CODIARTI+ " TEXT,"
  			    	   				+ FclespDBAdapter.DESDEFECHA+ " TEXT,"
  			    	    		   	+ FclespDBAdapter.PRECIO+ " REAL,"
  			    	    		   	+ FclespDBAdapter.COMISION+ " REAL);"; 

    private static final String CREATE_TABLE_RIESCLIE = 
    	       "create table riesclie (" + RiesclieDBAdapter.CODICLIE + " INTEGER primary key, " 
 								     + RiesclieDBAdapter.FACTPEND+ " REAL,"
 					   				 + RiesclieDBAdapter.CHEQPEND+ " REAL,"
 					   				 + RiesclieDBAdapter.CHEQDEVU+ " REAL,"
 					    		   	 + RiesclieDBAdapter.CHEQRECO+ " REAL,"
 					    		   	 + RiesclieDBAdapter.ALBAPEFA+ " REAL,"
 					    		   	 + RiesclieDBAdapter.RIESCONC+ " REAL,"
 					    		   	 + RiesclieDBAdapter.FECHACTU+ " REAL);"; 

    private static final String CREATE_TABLE_FCOMESP = 
    	       "create table f_comesp (" + FcomespDBAdapter.CODICOES + " INTEGER primary key, " 
 								     	 + FcomespDBAdapter.CODIARTI+ " TEXT,"
	 					   				 + FcomespDBAdapter.CODICOME+ " TEXT,"
	 					   				 + FcomespDBAdapter.DESDEFECHA+ " TEXT,"
	 					    		   	 + FcomespDBAdapter.HASTAFECHA+ " TEXT,"
	 					    		   	 + FcomespDBAdapter.PRECIO+ " REAL);"; 

    private static final String CREATE_TABLE_UNIDAD = 
  	       "create table unidad (" + UnidadDBAdapter.CODIUNID + " TEXT primary key, " 
 	    		   				   + UnidadDBAdapter.DESCUNID+ " TEXT);"; 
 	
    private static final String CREATE_TABLE_ARTIBAR = 
 	       "create table artibar (" + ArtibarDBAdapter.CODIGOBARRAS + " TEXT primary key, " 
			    					+ ArtibarDBAdapter.CODIARTI+ " TEXT,"
			    	   				+ ArtibarDBAdapter.CANTSTVT+ " REAL,"
			    	   				+ ArtibarDBAdapter.CODIUNID+ " TEXT);"; 

    private static final String CREATE_TABLE_FPREMINIMO = 
 	       "create table f_preminimo (" + FpreminimoDBAdapter.CODIPRMI + " INTEGER primary key, " 
								     	+ FpreminimoDBAdapter.CODIARTI+ " TEXT,"
	 					   				+ FpreminimoDBAdapter.DESDE+ " TEXT,"
	 					    		   	+ FpreminimoDBAdapter.HASTA+ " TEXT,"
	 					    		   	+ FpreminimoDBAdapter.MINIMO+ " REAL);"; 

    private static final String CREATE_TABLE_FPEVTCB = 
 	       "create table f_pevtcb (" + FpevtcbDBAdapter.CODIPECB + " INTEGER primary key, " 
 	    		   						+ FpevtcbDBAdapter.FECHA+ " TEXT,"
								     	+ FpevtcbDBAdapter.CODICLIE+ " INTEGER,"
	 					   				+ FpevtcbDBAdapter.CODIMCLI+ " TEXT,"
	 					    		   	+ FpevtcbDBAdapter.TEXTMCLI+ " TEXT);"; 

    private static final String CREATE_TABLE_FPEVTLN = 
   	       "create table f_pevtln (" + FpevtlnDBAdapter.CODIPELN + " INTEGER primary key, " 
  			    				     + FpevtlnDBAdapter.CODIPECB+ " INTEGER,"
  			    	   				 + FpevtlnDBAdapter.CODIARTI+ " TEXT,"
  			    	   				 + FpevtlnDBAdapter.CODIMART+ " TEXT,"
  			    	   				 + FpevtlnDBAdapter.CODITIPF+ " TEXT,"
  			    	    		   	 + FpevtlnDBAdapter.CANTIDAD+ " REAL,"
  			    	    		   	 + FpevtlnDBAdapter.PRECIO+ " REAL,"
  			    	    		   	 + FpevtlnDBAdapter.TEXTMART+ " TEXT,"
  			    	    		   	 + FpevtlnDBAdapter.CODIUNID+ " TEXT,"
  			    	    		   	 + FpevtlnDBAdapter.DESCARTI+ " TEXT,"
  			    	    		   	 + FpevtlnDBAdapter.TIPOPRECIO+ " TEXT,"
  			    	    		   	 + FpevtlnDBAdapter.CODIGOBARRAS+ " TEXT,"
  			    	    		   	 + FpevtlnDBAdapter.CANTTOTA+ " REAL);"; 

    private static final String CREATE_TABLE_UPRECIO = 
  	       "create table uprecio (" + UprecioDBAdapter.CODIUPRE + " INTEGER primary key, " 
  	    		   					+ UprecioDBAdapter.CODICLIE + " INTEGER,"
  	       							+ UprecioDBAdapter.CODIARTI + " TEXT,"
  	       							+ UprecioDBAdapter.PRECIO + " REAL);";
    
    private final Context context;  
    private DatabaseHelper DBHelper; 
    private SQLiteDatabase db; 
 
    private ConfigDBAdapter		configDBAdapter;
    private ArticuloDBAdapter   articuloDBAdapter;
    private ArtibarDBAdapter    artibarDBAdapter;
    private ClienteDBAdapter    clienteDBAdapter;
    private FclespDBAdapter     fclespDBAdapter;
    private FcliDBAdapter       fcliDBAdapter;
    private FcloferDBAdapter    fcloferDBAdapter;
    private FcomercDBAdapter    fcomercDBAdapter;
    private FcomespDBAdapter    fcomespDBAdapter;
    private FinciDBAdapter      finciDBAdapter;
    private FmenartDBAdapter    fmenartDBAdapter;
    private FmencliDBAdapter    fmencliDBAdapter;
    private FpreminimoDBAdapter fpreminimoDBAdapter;
    private ProvinciDBAdapter   provinciDBAdapter;
    private RiesclieDBAdapter   riesclieDBAdapter;
    private UnidadDBAdapter     unidadDBAdapter;
    private FpevtcbDBAdapter    fpevtcbDBAdapter;
    private FpevtlnDBAdapter    fpevtlnDBAdapter;
    private UprecioDBAdapter	uprecioDBAdapter;
    
    /** 
     * Constructor 
     * @param ctx 
     */ 
    public DBAdapter(Context ctx) 
    { 
        this.context = ctx; 
        this.DBHelper = new DatabaseHelper(this.context); 
    } 
 
    private static class DatabaseHelper extends SQLiteOpenHelper  
    { 
        DatabaseHelper(Context context)  
        { 
            super(context, DATABASE_NAME, null, DATABASE_VERSION); 
        } 
 
        @Override 
        public void onCreate(SQLiteDatabase db)  
        { 
        	this.onCreateConfig(db);
        	this.onCreateVentas(db);
        	this.onCreatePedidos(db);
        } 
 
        @Override 
        public void onUpgrade(SQLiteDatabase db, int oldVersion,  
        int newVersion)  
        {                
            // Adding any table mods to this guy here 
        } 
        
        private void onCreateConfig(SQLiteDatabase db){
        	db.execSQL(CREATE_TABLE_CONFIG); 
        	db.execSQL(CREATE_TABLE_UPRECIO);  
        }
        
        public void onCreateVentas(SQLiteDatabase db){
            db.execSQL(CREATE_TABLE_ARTICULO); 
            db.execSQL(CREATE_TABLE_CLIENTE); 
            db.execSQL(CREATE_TABLE_PROVINCI);            
            db.execSQL(CREATE_TABLE_FMENCLI);            
            db.execSQL(CREATE_TABLE_FCLI);            
            db.execSQL(CREATE_TABLE_FINCI);            
            db.execSQL(CREATE_TABLE_FCOMERC);            
            db.execSQL(CREATE_TABLE_FMENART);            
            db.execSQL(CREATE_TABLE_FCLOFER);            
            db.execSQL(CREATE_TABLE_FCLESP);            
            db.execSQL(CREATE_TABLE_RIESCLIE);            
            db.execSQL(CREATE_TABLE_FCOMESP);            
            db.execSQL(CREATE_TABLE_UNIDAD);            
            db.execSQL(CREATE_TABLE_ARTIBAR);            
            db.execSQL(CREATE_TABLE_FPREMINIMO);            
        }
        
        public void onCreatePedidos(SQLiteDatabase db){
            db.execSQL(CREATE_TABLE_FPEVTCB);            
            db.execSQL(CREATE_TABLE_FPEVTLN);            
        }
        
        public void onUpgradeVentas(SQLiteDatabase db){
        	db.execSQL("DROP TABLE IF EXISTS articulo"); 
        	db.execSQL("DROP TABLE IF EXISTS cliente"); 
        	db.execSQL("DROP TABLE IF EXISTS provinci"); 
        	db.execSQL("DROP TABLE IF EXISTS f_mencli"); 
        	db.execSQL("DROP TABLE IF EXISTS f_cli"); 
        	db.execSQL("DROP TABLE IF EXISTS f_inci"); 
        	db.execSQL("DROP TABLE IF EXISTS f_comerc"); 
        	db.execSQL("DROP TABLE IF EXISTS f_menart"); 
        	db.execSQL("DROP TABLE IF EXISTS f_tipfac"); 
        	db.execSQL("DROP TABLE IF EXISTS f_clofer"); 
        	db.execSQL("DROP TABLE IF EXISTS f_clesp"); 
        	db.execSQL("DROP TABLE IF EXISTS riesclie"); 
        	db.execSQL("DROP TABLE IF EXISTS f_comesp"); 
        	db.execSQL("DROP TABLE IF EXISTS unidad"); 
        	db.execSQL("DROP TABLE IF EXISTS artibar"); 
        	db.execSQL("DROP TABLE IF EXISTS f_preminimo");
        	
        	this.onCreateVentas(db);
        }
        
        public void onUpgradePedidos(SQLiteDatabase db){
        	db.execSQL("DROP TABLE IF EXISTS f_pevtcb"); 
        	db.execSQL("DROP TABLE IF EXISTS f_pevtln"); 

        	this.onCreatePedidos(db);
        }
    }  
 
   /** 
     * open the db 
     * @return this 
     * @throws SQLException 
     * return type: DBAdapter 
     */ 
    public DBAdapter open() throws SQLException  
    { 
        this.db = this.DBHelper.getWritableDatabase(); 
        configDBAdapter     = new ConfigDBAdapter(db);
        articuloDBAdapter   = new ArticuloDBAdapter(db);
        artibarDBAdapter    = new ArtibarDBAdapter(db);
        clienteDBAdapter    = new ClienteDBAdapter(db);
        fclespDBAdapter     = new FclespDBAdapter(db);
        fcliDBAdapter       = new FcliDBAdapter(db);
        fcloferDBAdapter    = new FcloferDBAdapter(db);
        fcomercDBAdapter    = new FcomercDBAdapter(db);
        fcomespDBAdapter    = new FcomespDBAdapter(db);
        finciDBAdapter      = new FinciDBAdapter(db);
        fmenartDBAdapter    = new FmenartDBAdapter(db);
        fmencliDBAdapter    = new FmencliDBAdapter(db);
        fpreminimoDBAdapter = new FpreminimoDBAdapter(db);
        provinciDBAdapter   = new ProvinciDBAdapter(db);
        riesclieDBAdapter   = new RiesclieDBAdapter(db);
        unidadDBAdapter     = new UnidadDBAdapter(db);

        fpevtcbDBAdapter = new FpevtcbDBAdapter(db);
        fpevtlnDBAdapter = new FpevtlnDBAdapter(db);
        
        uprecioDBAdapter = new UprecioDBAdapter(db);

        return this; 
    } 
 
    /** 
     * close the db  
     * return type: void 
     */ 
    public void close()  
    { 
        this.DBHelper.close(); 
    } 

    public void limpiaVentas(){
    	this.DBHelper.onUpgradeVentas(this.db);
    }

    public void limpiaPedidos(){
    	this.DBHelper.onUpgradePedidos(this.db);
    }
    
    public void procesaLineaTexto(String texto){
    	//Debemos aadir un campo ms al final de la lnea ya que 
    	//la funcin split slo procesa campos hasta el ltimo pipe con valor.
    	//En los casos de que los ltimos campos sean vacos, estos no se
    	//incluiran con split.
    	texto = texto + "|0";
    	String[] linea = texto.split("\\|");
    	
    	String tabla = linea[0];
    	String oper  = tabla.substring(0, 1); //I:Insert; U:Update; D:Delete;
    	tabla        = tabla.substring(1);    //Nombre de la tabla

    	
    	if (tabla.equalsIgnoreCase(ArticuloDBAdapter.DATABASE_TABLE)) {
    		if (oper.equalsIgnoreCase("I"))
    			articuloDBAdapter.createFromString(linea);
    		else if (oper.equalsIgnoreCase("U"))
    			articuloDBAdapter.updateFromString(linea);
    		else if (oper.equalsIgnoreCase("D"))
    			articuloDBAdapter.deleteFromString(linea);
        } 
    	else if (tabla.equalsIgnoreCase(ArtibarDBAdapter.DATABASE_TABLE)) {
    		if (oper.equalsIgnoreCase("I"))
    			artibarDBAdapter.createFromString(linea);
    		else if (oper.equalsIgnoreCase("U"))
    			artibarDBAdapter.updateFromString(linea);
    		else if (oper.equalsIgnoreCase("D"))
    			artibarDBAdapter.deleteFromString(linea);
        }
    	else if (tabla.equalsIgnoreCase(ClienteDBAdapter.DATABASE_TABLE)) {
    		if (oper.equalsIgnoreCase("I"))
    			clienteDBAdapter.createFromString(linea);
    		else if (oper.equalsIgnoreCase("U"))
    			clienteDBAdapter.updateFromString(linea);
    		else if (oper.equalsIgnoreCase("D"))
    			clienteDBAdapter.deleteFromString(linea);
        }
    	else if (tabla.equalsIgnoreCase(FclespDBAdapter.DATABASE_TABLE)) {
    		if (oper.equalsIgnoreCase("I"))
    			fclespDBAdapter.createFromString(linea);
    		else if (oper.equalsIgnoreCase("U"))
    			fclespDBAdapter.updateFromString(linea);
    		else if (oper.equalsIgnoreCase("D"))
    			fclespDBAdapter.deleteFromString(linea);
        }
    	else if (tabla.equalsIgnoreCase(FcliDBAdapter.DATABASE_TABLE)) {
    		if (oper.equalsIgnoreCase("I"))
    			fcliDBAdapter.createFromString(linea);
    		else if (oper.equalsIgnoreCase("U"))
    			fcliDBAdapter.updateFromString(linea);
    		else if (oper.equalsIgnoreCase("D"))
    			fcliDBAdapter.deleteFromString(linea);
        }
    	else if (tabla.equalsIgnoreCase(FcloferDBAdapter.DATABASE_TABLE)) {
    		if (oper.equalsIgnoreCase("I"))
    			fcloferDBAdapter.createFromString(linea);
    		else if (oper.equalsIgnoreCase("U"))
    			fcloferDBAdapter.updateFromString(linea);
    		else if (oper.equalsIgnoreCase("D"))
    			fcloferDBAdapter.deleteFromString(linea);
        }
    	else if (tabla.equalsIgnoreCase(FcomercDBAdapter.DATABASE_TABLE)) {
    		if (oper.equalsIgnoreCase("I"))
    			fcomercDBAdapter.createFromString(linea);
    		else if (oper.equalsIgnoreCase("U"))
    			fcomercDBAdapter.updateFromString(linea);
    		else if (oper.equalsIgnoreCase("D"))
    			fcomercDBAdapter.deleteFromString(linea);
        }
    	else if (tabla.equalsIgnoreCase(FcomespDBAdapter.DATABASE_TABLE)) {
    		if (oper.equalsIgnoreCase("I"))
    			fcomespDBAdapter.createFromString(linea);
    		else if (oper.equalsIgnoreCase("U"))
    			fcomespDBAdapter.updateFromString(linea);
    		else if (oper.equalsIgnoreCase("D"))
    			fcomespDBAdapter.deleteFromString(linea);
        }
    	else if (tabla.equalsIgnoreCase(FinciDBAdapter.DATABASE_TABLE)) {
    		if (oper.equalsIgnoreCase("I"))
    			finciDBAdapter.createFromString(linea);
    		else if (oper.equalsIgnoreCase("U"))
    			finciDBAdapter.updateFromString(linea);
    		else if (oper.equalsIgnoreCase("D"))
    			finciDBAdapter.deleteFromString(linea);
        }
    	else if (tabla.equalsIgnoreCase(FmenartDBAdapter.DATABASE_TABLE)) {
    		if (oper.equalsIgnoreCase("I"))
    			fmenartDBAdapter.createFromString(linea);
    		else if (oper.equalsIgnoreCase("U"))
    			fmenartDBAdapter.updateFromString(linea);
    		else if (oper.equalsIgnoreCase("D"))
    			fmenartDBAdapter.deleteFromString(linea);
        }
    	else if (tabla.equalsIgnoreCase(FmencliDBAdapter.DATABASE_TABLE)) {
    		if (oper.equalsIgnoreCase("I"))
    			fmencliDBAdapter.createFromString(linea);
    		else if (oper.equalsIgnoreCase("U"))
    			fmencliDBAdapter.updateFromString(linea);
    		else if (oper.equalsIgnoreCase("D"))
    			fmencliDBAdapter.deleteFromString(linea);
        }
    	else if (tabla.equalsIgnoreCase(FpreminimoDBAdapter.DATABASE_TABLE)) {
    		if (oper.equalsIgnoreCase("I"))
    			fpreminimoDBAdapter.createFromString(linea);
    		else if (oper.equalsIgnoreCase("U"))
    			fpreminimoDBAdapter.updateFromString(linea);
    		else if (oper.equalsIgnoreCase("D"))
    			fpreminimoDBAdapter.deleteFromString(linea);
        }
    	else if (tabla.equalsIgnoreCase(ProvinciDBAdapter.DATABASE_TABLE)) {
    		if (oper.equalsIgnoreCase("I"))
    			provinciDBAdapter.createFromString(linea);
    		else if (oper.equalsIgnoreCase("U"))
    			provinciDBAdapter.updateFromString(linea);
    		else if (oper.equalsIgnoreCase("D"))
    			provinciDBAdapter.deleteFromString(linea);
        }
    	else if (tabla.equalsIgnoreCase(RiesclieDBAdapter.DATABASE_TABLE)) {
    		if (oper.equalsIgnoreCase("I"))
    			riesclieDBAdapter.createFromString(linea);
    		else if (oper.equalsIgnoreCase("U"))
    			riesclieDBAdapter.updateFromString(linea);
    		else if (oper.equalsIgnoreCase("D"))
    			riesclieDBAdapter.deleteFromString(linea);
        }
    	else if (tabla.equalsIgnoreCase(UnidadDBAdapter.DATABASE_TABLE)) {
    		if (oper.equalsIgnoreCase("I"))
    			unidadDBAdapter.createFromString(linea);
    		else if (oper.equalsIgnoreCase("U"))
    			unidadDBAdapter.updateFromString(linea);
    		else if (oper.equalsIgnoreCase("D"))
    			unidadDBAdapter.deleteFromString(linea);
        }
    	else if (tabla.equalsIgnoreCase(FpevtcbDBAdapter.DATABASE_TABLE)) {
    		if (oper.equalsIgnoreCase("I"))
    			fpevtcbDBAdapter.createFromString(linea);
        }
    	else if (tabla.equalsIgnoreCase(FpevtlnDBAdapter.DATABASE_TABLE)) {
    		if (oper.equalsIgnoreCase("I"))
    			fpevtlnDBAdapter.createFromString(linea);
        }

    }

    public long createConfig(String ip_destino, 
			String nom_terminal, 
			int id_terminal,
			int id_empresa){ 
    	return this.configDBAdapter.create(ip_destino, nom_terminal, id_terminal, id_empresa);
    } 
	    
    public Cursor getConfig() {
    	return configDBAdapter.getAll();
    }
    
    public Cursor getAllConditionalCliente(String where)  throws SQLException { 
    	return clienteDBAdapter.getAllConditional(where);
    }

    public Cursor getAllConditionalArticulo(String where)  throws SQLException { 
    	return articuloDBAdapter.getAllConditional(where);
    }
    
    public Cursor getCliente(int codiclie)  throws SQLException { 
    	return clienteDBAdapter.get(codiclie);
    }

    public Cursor getRiesclie(int codiclie)  throws SQLException { 
    	return riesclieDBAdapter.get(codiclie);
    }

    public Cursor getFcli(long codiclie)  throws SQLException { 
    	return fcliDBAdapter.get(codiclie);
    }

    public Cursor getFinci(String codiinci)  throws SQLException { 
    	return finciDBAdapter.get(codiinci);
    }

    public Cursor getAllFmencli()  throws SQLException { 
    	return fmencliDBAdapter.getAll();
    }
    
    public Cursor getFmencli(String codimcli)  throws SQLException { 
    	return fmencliDBAdapter.get(codimcli);
    }
    
    public Cursor getAllConditionalMencli(String where)  throws SQLException { 
    	return this.fmencliDBAdapter.getAllConditional(where);
    }
    
    public Cursor getAllFmenart()  throws SQLException { 
    	return fmenartDBAdapter.getAll();
    }
    
    public Cursor getFmenart(String codimart)  throws SQLException { 
    	return fmenartDBAdapter.get(codimart);
    }
    
    public Cursor getAllConditionalMenart(String where)  throws SQLException { 
    	return this.fmenartDBAdapter.getAllConditional(where);
    }
    
    public Cursor getArticulo(String codiarti)  throws SQLException { 
    	return articuloDBAdapter.get(codiarti);
    }

    public Cursor getFpreminimo(String vigencia, String articulo)  throws SQLException { 
    	return fpreminimoDBAdapter.get(vigencia, articulo);
    }

    public Cursor getFclesp(String vigencia, long cliente, String articulo)  throws SQLException { 
    	return fclespDBAdapter.get(vigencia, cliente, articulo);
    }

    public Cursor getFcomesp(String vigencia, String codicome, String articulo)  throws SQLException { 
    	return fcomespDBAdapter.get(vigencia, codicome, articulo);
    }

    public Cursor getFcomerc(String codicome)  throws SQLException { 
    	return fcomercDBAdapter.get(codicome);
    }

    public Cursor getFclofer(String vigencia, long cliente, String articulo)  throws SQLException { 
    	return fcloferDBAdapter.get(vigencia, cliente, articulo);
    }

    public Long createPevtcb(String fecha, 
				long codiclie, 
				String codimcli, 
				String textmcli) throws SQLException{
    	return fpevtcbDBAdapter.create(fecha, codiclie, codimcli, textmcli);
	}
	
	public Cursor getAllPevtcb() throws SQLException{
		return fpevtcbDBAdapter.getAll();
	}
	
	public Cursor getPevtcb(long cliente, String fecha) throws SQLException{
		return fpevtcbDBAdapter.get(cliente, fecha);
	}
	
    public boolean updatePevtcb(long codipecb, 
            String fecha, 
			  long codiclie, 
            String codimcli, 
            String textmcli){ 

      return this.fpevtcbDBAdapter.update(codipecb, fecha, codiclie, codimcli, textmcli);  
  } 
	
	public Boolean deletePevtcb(long codipecb) throws SQLException {
		this.fpevtlnDBAdapter.deleteByFpevtcb(codipecb);
		return this.fpevtcbDBAdapter.delete(codipecb);
	}
	
	public Cursor getAllPevtln() throws SQLException{
		return fpevtlnDBAdapter.getAll();
	}
	
	public Cursor getPevtln(long codipeln) throws SQLException{
		return this.fpevtlnDBAdapter.get(codipeln);
	}
	
	public Cursor getPevtlnByCB(long pevtcb) throws SQLException{
		return this.fpevtlnDBAdapter.getByFpevtcb(pevtcb);
	}

	public Cursor getAllLinArt(long codipecb) throws SQLException{
		return this.fpevtlnDBAdapter.getAllLinArt(codipecb);
	}
	
	public Cursor getLinArt(long codipeln) throws SQLException{
		return this.fpevtlnDBAdapter.getLinArt(codipeln);
	}

	public Boolean deletePevtln(long pevtln) throws SQLException {
		return this.fpevtlnDBAdapter.delete(pevtln);
	}
	
	public SQLiteDatabase getDb() throws SQLException {
		return this.db;
	}
	
	public Cursor getUnidad() throws SQLException{
		return this.unidadDBAdapter.getAll();
	}
	
	public Cursor getArtibar(String codigobarras) throws SQLException{
		return this.artibarDBAdapter.get(codigobarras);
	}
	
	public Cursor getArtibarByCodiarti(String codiarti) throws SQLException{
		return this.artibarDBAdapter.getByCodiarti(codiarti);
	}
	
    public long createFpevtln(long codipecb, 
            String codiarti, 
            String codimart, 
            double cantidad, 
            double precio, 
            String textmart, 
            String codiunid, 
            String descarti,
            String tipoprecio,
            String codigobarras,
            double canttota){ 
    	return this.fpevtlnDBAdapter.create(codipecb, codiarti, codimart, cantidad, precio, textmart, codiunid, descarti, tipoprecio, codigobarras, canttota);
    }
	
	public boolean updateFpevtln( long codipeln, 
			  long codipecb, 
            String codiarti, 
            String codimart, 
            double cantidad, 
            double precio, 
            String textmart, 
            String codiunid, 
            String descarti,
            String tipoprecio,
            String codigobarras,
            double canttota){ 
		return this.fpevtlnDBAdapter.update(codipeln, codipecb, codiarti, codimart, cantidad, precio, textmart, codiunid, descarti, tipoprecio, codigobarras, canttota);
	}
	
    public long createUprecio(long codiclie, 
            			String codiarti, 
            			double precio){ 
		return this.uprecioDBAdapter.create(codiclie, codiarti, precio);
    } 
    
    public Cursor getUprecio(long codiclie, 
			String codiarti) throws SQLException { 
		return this.uprecioDBAdapter.get(codiclie, codiarti);
	} 
		    
    public boolean updateUprecio(long codiclie, 
					String codiarti, 
					double precio){ 
		return this.uprecioDBAdapter.update(codiclie, codiarti, precio);
	} 
}
