package com.ventas.database;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;

public class FcliDBAdapter {
	public static final String CODICLIE = "_id"; 
    public static final String CODIINCI = "codiinci";
    public static final String CODIMCLI = "codimcli"; 
    public static final String CODICOME = "codicome";
    public static final String OBSERVACION1 = "observacion1";
    public static final String OBSERVACION2 = "observacion2";
    public static final String CODIINCITMP = "codiincitmp";

    public static final String DATABASE_TABLE = "f_cli"; 
 
    private SQLiteDatabase mDb; 

    /** 
     * Constructor - takes the SQLiteDatabase to access to the database
     *  
     * @param db 
     *            the SQLiteDatabase within which to work 
     */ 
    public FcliDBAdapter(SQLiteDatabase db) { 
        this.mDb = db; 
    } 
 

    
    /** 
     * Create a new cliente. If the cliente is successfully created return the new 
     * rowId for that cliente, otherwise return a -1 to indicate failure. 
     *  
     * @param codiclie 
     * @param codiinci 
     * @param codimcli 
     * @param codicome 
     * @param observacion1 
     * @param observacion2 
     * @param codiincitmp 
     * @return rowId or -1 if failed 
     */ 
    public long create(long codiclie, 
    		                  String codiinci, 
    		                  String codimcli, 
    		                  String codicome, 
    		                  String observacion1, 
    		                  String observacion2, 
    		                  String codiincitmp){ 
        ContentValues initialValues = new ContentValues(); 
        initialValues.put(CODICLIE, codiclie); 
        initialValues.put(CODIINCI, codiinci); 
        initialValues.put(CODIMCLI, codimcli); 
        initialValues.put(CODICOME, codicome); 
        initialValues.put(OBSERVACION1, observacion1); 
        initialValues.put(OBSERVACION2, observacion2); 
        initialValues.put(CODIINCITMP, codiincitmp); 

        return this.mDb.insert(DATABASE_TABLE, null, initialValues); 
    } 

    
    /** 
     * Delete the cliente with the given rowId 
     *  
     * @param codiclie 
     * @return true if deleted, false otherwise 
     */ 
    public boolean delete(long codiclie) { 
 
        return this.mDb.delete(DATABASE_TABLE, CODICLIE + "=" + codiclie, null) > 0; 
    } 
 
    /** 
     * Return a Cursor over the list of all clientes in the database 
     *  
     * @return Cursor over all clientes
     */ 
    public Cursor getAll() { 
        return this.mDb.query(DATABASE_TABLE, new String[] { CODICLIE, 
        		CODIINCI, CODIMCLI, CODICOME, OBSERVACION1, OBSERVACION2,
        		CODIINCITMP }, null, null, null, null, null); 
} 
 
    /** 
     * Return a Cursor positioned at the cliente that matches the given rowId 
     * @param codiclie 
     * @return Cursor positioned to matching cliente, if found 
     * @throws SQLException if cliente could not be found/retrieved 
     */ 
    public Cursor get(long codiclie) throws SQLException { 
 
        Cursor mCursor = 
 
        this.mDb.query(true, DATABASE_TABLE, new String[] { CODICLIE, 
        		CODIINCI, CODIMCLI, CODICOME, OBSERVACION1, OBSERVACION2,
        		CODIINCITMP }, CODICLIE + "=" + codiclie, null, null, null, null, null); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 


    /** 
     * Update the cliente. 
     *  
     * @param codiclie 
     * @param codiinci 
     * @param codimcli 
     * @param codicome 
     * @param observacion1 
     * @param observacion2 
     * @param codiincitmp 
     * @return true if the note was successfully updated, false otherwise 
     */ 
    public boolean update(long codiclie, 
 					             String codiinci, 
					             String codimcli, 
					             String codicome, 
					             String observacion1, 
					             String observacion2, 
					             String codiincitmp){ 
        ContentValues args = new ContentValues(); 
        args.put(CODICLIE, codiclie); 
        args.put(CODIINCI, codiinci); 
        args.put(CODIMCLI, codimcli); 
        args.put(CODICOME, codicome); 
        args.put(OBSERVACION1, observacion1); 
        args.put(OBSERVACION2, observacion2); 
        args.put(CODIINCITMP, codiincitmp); 

        return this.mDb.update(DATABASE_TABLE, args, CODICLIE + "=" + codiclie, null) >0;  
    } 

    /** 
     * Create a new f_cli from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public long createFromString(String[] linea){
    	long    codiclie     = Long.valueOf(linea[1]).longValue();
        String codiinci     = linea[2]; 
        String codimcli     = linea[3]; 
        String codicome     = linea[4]; 
        String observacion1 = linea[5]; 
        String observacion2 = linea[6]; 
        String codiincitmp  = linea[7];

        return create(codiclie, codiinci, codimcli, codicome, observacion1, observacion2, codiincitmp);
    }

    /** 
     * Update a new f_cli from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public boolean updateFromString(String[] linea){
        
    	ContentValues args = new ContentValues(); 
    	
    	Long    codiclie     = Long.valueOf(linea[1]);
    	args.put(CODICLIE, codiclie); 
    	
    	for (int i=2; i < (linea.length - 1); i = i+2) {
    		args.put(linea[i], linea[i+1]); 
    	}
    	return this.mDb.update(DATABASE_TABLE, args, CODICLIE + "=" + codiclie , null) >0;  
    	 
    }

    /** 
     * Delete f_cli from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public void deleteFromString(String[] linea){
    	for (int i=1; i<linea.length; i++){
    		long codiclie = Long.valueOf(linea[i]).longValue();
    		delete(codiclie);
    	}
    }
}
