package com.ventas.database;

import java.text.NumberFormat;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;

public class FcloferDBAdapter {
	public static final String CODICOFER = "_id"; 
    public static final String CODICLIE  = "codiclie";
    public static final String CODIARTI  = "codiarti"; 
    public static final String FECHDESD  = "fechdesd";
    public static final String FECHHAST  = "fechhast";
    public static final String PRECCOFE  = "preccofe";
    public static final String COMISION  = "comision";
    public static final String CANTDESC  = "cantdesc";
    public static final String CANTREGAL = "cantregal";
    public static final String CODIARRE  = "codiarre";
    
    public static final String DATABASE_TABLE = "f_clofer"; 
 
    private SQLiteDatabase mDb; 
 
    /** 
     * Constructor - takes the SQLiteDatabase to access to the database
     *  
     * @param db 
     *            the SQLiteDatabase within which to work 
     */ 
    public FcloferDBAdapter(SQLiteDatabase db) { 
        this.mDb = db; 
    } 
 
 
    /** 
     * Create a new f_clofer. If the f_clofer is successfully created return the new 
     * rowId for that f_clofer, otherwise return a -1 to indicate failure. 
     *  
     * @param codicofer 
     * @param codiclie 
     * @param codiarti 
     * @param fechdesd 
     * @param fechhast 
     * @param preccofe 
     * @param comision 
     * @param cantdesc 
     * @param cantregal 
     * @param codiarre 
     * @return rowId or -1 if failed 
     */ 
    public long create(long codicofer, 
    						  long codiclie, 
    		                  String codiarti, 
    		                  String fechdesd, 
    		                  String fechhast, 
    		                  double preccofe, 
    		                  double comision, 
    		                  double cantdesc, 
    		                  double cantregal,
    		                  String codiarre){ 
        ContentValues initialValues = new ContentValues(); 
        initialValues.put(CODICOFER, codicofer); 
        initialValues.put(CODICLIE, codiclie); 
        initialValues.put(CODIARTI, codiarti); 
        initialValues.put(FECHDESD, fechdesd); 
        initialValues.put(FECHHAST, fechhast); 
        initialValues.put(PRECCOFE, preccofe); 
        initialValues.put(COMISION, comision); 
        initialValues.put(CANTDESC, cantdesc); 
        initialValues.put(CANTREGAL, cantregal); 
        initialValues.put(CODIARRE, codiarre); 

        return this.mDb.insert(DATABASE_TABLE, null, initialValues); 
    } 

    
    /** 
     * Delete the f_clofer with the given rowId 
     *  
     * @param codicofer 
     * @return true if deleted, false otherwise 
     */ 
    public boolean delete(long codicofer) { 
 
        return this.mDb.delete(DATABASE_TABLE, CODICOFER + "=" + codicofer, null) > 0; 
    } 
 
    /** 
     * Return a Cursor over the list of all f_clofers in the database 
     *  
     * @return Cursor over all f_clofers
     */ 
    public Cursor getAll() { 
        return this.mDb.query(DATABASE_TABLE, new String[] { CODICOFER, 
        		CODICLIE, CODIARTI, FECHDESD, FECHHAST, PRECCOFE,
        		COMISION, CANTDESC, CANTREGAL, CODIARRE }, null, null, null, null, null); 
} 
 
    /** 
     * Return a Cursor positioned at the f_clofer that matches the given rowId 
     * @param codicofer 
     * @return Cursor positioned to matching f_clofer, if found 
     * @throws SQLException if f_clofer could not be found/retrieved 
     */ 
    public Cursor get(long codicofer) throws SQLException { 
 
        Cursor mCursor = 
 
        this.mDb.query(true, DATABASE_TABLE, new String[] { CODICOFER, 
        		CODICLIE, CODIARTI, FECHDESD, FECHHAST, PRECCOFE,
        		COMISION, CANTDESC, CANTREGAL, CODIARRE }, CODICOFER + "=" + codicofer, null, null, null, null, null); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 

    /** 
     * Return a Cursor positioned at the f_clesp that matches the given vigencia, cliente and articulo 
     * @param vigencia 
     * @param cliente 
     * @param articulo 
     * @return Cursor positioned to matching f_clesp, if found 
     * @throws SQLException if f_clesp could not be found/retrieved 
     */ 
    public Cursor get(String vigencia, long cliente, String articulo) throws SQLException { 
        Cursor mCursor = this.mDb.query(DATABASE_TABLE, new String[] { CODICOFER, 
        		CODICLIE, CODIARTI, FECHDESD, FECHHAST, PRECCOFE,
        		COMISION, CANTDESC, CANTREGAL, CODIARRE }, 
        		            CODICLIE + "=" + cliente + 
        		  " AND " + CODIARTI + "= '" + articulo + "'" + 
        		  " AND " + FECHHAST + ">= '" + vigencia + "'", null, null, null, FECHDESD); 

        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 



    /** 
     * Update the f_clofer. 
     *  
     * @param codicofer 
     * @param codiclie 
     * @param codiarti 
     * @param fechdesd 
     * @param fechhast 
     * @param preccofe 
     * @param comision 
     * @param cantdesc 
     * @param cantregal 
     * @param codiarre 
     * @return true if the note was successfully updated, false otherwise 
     */ 
    public boolean update(long codicofer, 
			  long codiclie, 
              String codiarti, 
              String fechdesd, 
              String fechhast, 
              double preccofe, 
              double comision, 
              double cantdesc, 
              double cantregal,
              String codiarre){ 
        ContentValues args = new ContentValues(); 
        args.put(CODICOFER, codicofer); 
        args.put(CODICLIE, codiclie); 
        args.put(CODIARTI, codiarti); 
        args.put(FECHDESD, fechdesd); 
        args.put(FECHHAST, fechhast); 
        args.put(PRECCOFE, preccofe); 
        args.put(COMISION, comision); 
        args.put(CANTDESC, cantdesc); 
        args.put(CANTREGAL, cantregal); 
        args.put(CODIARRE, codiarre); 

        return this.mDb.update(DATABASE_TABLE, args, CODICOFER + "=" + codicofer, null) >0;  
    } 

    /** 
     * Create a new f_clofer from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public long createFromString(String[] linea){
    	NumberFormat nf  = NumberFormat.getInstance();
    	long    codicofer = Long.valueOf(linea[1]).longValue();
		long    codiclie  = Long.valueOf(linea[2]).longValue(); 
        String codiarti  = linea[3]; 
        String fechdesd  = linea[4]; 
        String fechhast  = linea[5]; 
        double preccofe  = 0; 
        double comision  = 0; 
        double cantdesc  = 0; 
        double cantregal = 0;
        String codiarre  = linea[10];
        
    	try{
    		preccofe = nf.parse(linea[6]).doubleValue();
    	}catch(Exception e){
       	}
    	
    	try{
    		comision = nf.parse(linea[7]).doubleValue();
    	}catch(Exception e){
       	}
    	
    	try{
    		cantdesc = nf.parse(linea[8]).doubleValue();
    	}catch(Exception e){
       	}
    	
    	try{
    		cantregal = nf.parse(linea[9]).doubleValue();
    	}catch(Exception e){
       	}
    	
    	return create(codicofer, codiclie, codiarti, fechdesd, fechhast, preccofe, comision, cantdesc, cantregal, codiarre);
    }

    /** 
     * Update a new f_clofer from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public boolean updateFromString(String[] linea){
    	
    	NumberFormat nf = NumberFormat.getInstance();
    	ContentValues args = new ContentValues(); 
    	double valor = 0;
    	 
    	Long   codicofer = Long.valueOf(linea[1]);
    	args.put(CODICOFER, codicofer); 
    	
    	for (int i=2; i < (linea.length - 1); i = i+2) {
    		
    		if ( linea[i].equalsIgnoreCase(CODICLIE) ) { //es campo LONG
    			Long codiclie   = Long.valueOf( linea[i+1] ); 
    			args.put(linea[i], codiclie); 
    		}
    		else {
	    		if ( linea[i].equalsIgnoreCase(PRECCOFE) ||
	    			linea[i].equalsIgnoreCase(COMISION) ||
	    			linea[i].equalsIgnoreCase(CANTDESC) ||
	    			linea[i].equalsIgnoreCase(CANTREGAL) ) { //es campo DOUBLE
	    			try{
	    				valor = nf.parse( linea[i+1] ).doubleValue();
	    			}catch(Exception e){
	    	       	}
	    			args.put(linea[i], valor); 
	    		}
	    		else { //es campo string
	    			args.put(linea[i], linea[i+1]); 
	    		}
    		}
    	}
    	return this.mDb.update(DATABASE_TABLE, args, CODICOFER + "=" + codicofer, null) >0;  
    	
    }

    /** 
     * Delete f_clofer from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public void deleteFromString(String[] linea){
    	for (int i=1; i<linea.length; i++){
    		long codicofer = Long.valueOf(linea[i]).longValue();
    		delete(codicofer);
    	}
    }
}
