package com.ventas.database;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;

public class FcomercDBAdapter {
	public static final String CODICOME = "_id"; 
    public static final String DESCCOME = "desccome";

    public static final String DATABASE_TABLE = "f_comerc"; 
 
    private SQLiteDatabase mDb; 
 
    /** 
     * Constructor - takes the SQLiteDatabase to access to the database
     *  
     * @param db 
     *            the SQLiteDatabase within which to work 
     */ 
    public FcomercDBAdapter(SQLiteDatabase db) { 
        this.mDb = db; 
    } 

    /** 
     * Create a new f_comerc. If the f_comerc is successfully created return the new 
     * rowId for that f_comerc, otherwise return a -1 to indicate failure. 
     *  
     * @param codicome 
     * @param desccome 
     * @return rowId or -1 if failed 
     */ 
    public long create(String codicome, String desccome){ 
        ContentValues initialValues = new ContentValues(); 
        initialValues.put(CODICOME, codicome); 
        initialValues.put(DESCCOME, desccome); 
        return this.mDb.insert(DATABASE_TABLE, null, initialValues); 
    } 
 
    /** 
     * Delete the f_comerc with the given rowId 
     *  
     * @param codicome 
     * @return true if deleted, false otherwise 
     */ 
    public boolean delete(String codicome) { 
 
        return this.mDb.delete(DATABASE_TABLE, CODICOME + "= '" + codicome + "'", null) > 0; 
    } 
 
    /** 
     * Return a Cursor over the list of all f_comercs in the database 
     *  
     * @return Cursor over all f_comercs 
     */ 
    public Cursor getAll() { 
 
        return this.mDb.query(DATABASE_TABLE, new String[] { CODICOME, 
        		DESCCOME }, null, null, null, null, null); 
    } 
 
    /** 
     * Return a Cursor positioned at the f_comerc that matches the given rowId 
     * @param codicome 
     * @return Cursor positioned to matching f_comerc, if found 
     * @throws SQLException if f_comerc could not be found/retrieved 
     */ 
    public Cursor get(String codicome) throws SQLException { 
 
        Cursor mCursor = 
 
        this.mDb.query(true, DATABASE_TABLE, new String[] { CODICOME, 
        		DESCCOME }, CODICOME + "= '" + codicome + "'", null, null, null, null, null); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 
 

    /** 
     * Update the f_comerc. 
     *  
     * @param codicome 
     * @param desccome 
     * @return true if the note was successfully updated, false otherwise 
     */ 
    public boolean update(String codicome, String desccome){ 
        ContentValues args = new ContentValues(); 
        args.put(CODICOME, codicome); 
        args.put(DESCCOME, desccome); 
 
        return this.mDb.update(DATABASE_TABLE, args, CODICOME + "= '" + codicome + "'", null) >0;  
    } 

    /** 
     * Create a new f_comerc from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public long createFromString(String[] linea){
    	String codicome = linea[1];
    	String desccome = linea[2];
    	
    	return create(codicome, desccome);
    }
    
    /** 
     * Update a new f_comerc from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public boolean updateFromString(String[] linea){
    	
    	ContentValues args = new ContentValues(); 
    	
    	String codicome = linea[1];
    	args.put(CODICOME, codicome); 
    	
    	for (int i=2; i < (linea.length - 1); i = i+2) {
    		args.put(linea[i], linea[i+1]); 
    	}
    	return this.mDb.update(DATABASE_TABLE, args, CODICOME + "='" + codicome + "'", null) >0;  
    	
    }

    /** 
     * Delete f_comerc from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public void deleteFromString(String[] linea){
    	for (int i=1; i<linea.length; i++){
    		delete(linea[i]);
    	}
    }
}
