package com.ventas.database;

import java.text.NumberFormat;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;

public class FcomespDBAdapter {
	public static final String CODICOES = "_id"; 
    public static final String CODIARTI = "codiarti";
    public static final String CODICOME = "codicome"; 
    public static final String DESDEFECHA = "desdefecha";
    public static final String HASTAFECHA = "hastafecha";
    public static final String PRECIO = "precio";
    
    public static final String DATABASE_TABLE = "f_comesp"; 
 
    private SQLiteDatabase mDb; 
 
    /** 
     * Constructor - takes the SQLiteDatabase to access to the database
     *  
     * @param db 
     *            the SQLiteDatabase within which to work 
     */ 
    public FcomespDBAdapter(SQLiteDatabase db) { 
        this.mDb = db; 
    } 

     /** 
     * Create a new f_comesp. If the f_comesp is successfully created return the new 
     * rowId for that f_comesp, otherwise return a -1 to indicate failure. 
     *  
     * @param codicoes 
     * @param codiarti 
     * @param codicome 
     * @param desdefecha 
     * @param hastafecha 
     * @param precio 
     * @return rowId or -1 if failed 
     */ 
    public long create(int codicoes, 
							  String codiarti, 
				              String codicome, 
				              String desdefecha, 
				              String hastafecha, 
				              double precio){ 
        ContentValues initialValues = new ContentValues(); 
        initialValues.put(CODICOES, codicoes); 
        initialValues.put(CODIARTI, codiarti); 
        initialValues.put(CODICOME, codicome); 
        initialValues.put(DESDEFECHA, desdefecha); 
        initialValues.put(HASTAFECHA, hastafecha); 
        initialValues.put(PRECIO, precio); 

        return this.mDb.insert(DATABASE_TABLE, null, initialValues); 
    } 

    
    /** 
     * Delete the f_comesp with the given rowId 
     *  
     * @param codicoes 
     * @return true if deleted, false otherwise 
     */ 
    public boolean delete(int codicoes) { 
 
        return this.mDb.delete(DATABASE_TABLE, CODICOES + "=" + codicoes, null) > 0; 
    } 
 
    /** 
     * Return a Cursor over the list of all f_comesps in the database 
     *  
     * @return Cursor over all f_comesps
     */ 
    public Cursor getAll() { 
        return this.mDb.query(DATABASE_TABLE, new String[] { CODICOES, 
        		CODIARTI, CODICOME, DESDEFECHA, HASTAFECHA, PRECIO }, null, null, null, null, null); 
} 
 
    /** 
     * Return a Cursor positioned at the f_comesp that matches the given rowId 
     * @param codicoes 
     * @return Cursor positioned to matching f_comesp, if found 
     * @throws SQLException if f_comesp could not be found/retrieved 
     */ 
    public Cursor get(int codicoes) throws SQLException { 
 
        Cursor mCursor = 
 
        this.mDb.query(true, DATABASE_TABLE, new String[] { CODICOES, 
        		CODIARTI, CODICOME, DESDEFECHA, HASTAFECHA, PRECIO }, CODICOES + "=" + codicoes, null, null, null, null, null); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 

    /** 
     * Return a Cursor positioned at the f_clesp that matches the given vigencia, codicome and articulo 
     * @param vigencia 
     * @param codicome 
     * @param articulo 
     * @return Cursor positioned to matching f_clesp, if found 
     * @throws SQLException if f_clesp could not be found/retrieved 
     */ 
    public Cursor get(String vigencia, String codicome, String articulo) throws SQLException { 
        Cursor mCursor = this.mDb.query(DATABASE_TABLE, new String[] { CODICOES, 
        		CODIARTI, CODICOME, DESDEFECHA, HASTAFECHA, PRECIO }, 
        		                CODICOME + "= '" + codicome + "'" + 
            		  " AND " + CODIARTI + "= '" + articulo + "'" + 
        		      " AND (" + HASTAFECHA + ">= '" + vigencia + "' OR " + HASTAFECHA + " = '')", null, null, null, DESDEFECHA); 

        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 


    /** 
     * Update the f_comesp. 
     *  
     * @param codicoes 
     * @param codiarti 
     * @param codicome 
     * @param desdefecha 
     * @param hastafecha 
     * @param precio 
     * @return true if the note was successfully updated, false otherwise 
     */ 
    public boolean update(int codicoes, 
			  					  String codiarti, 
                                  String codicome, 
					              String desdefecha, 
					              String hastafecha, 
					              double precio){ 
        ContentValues args = new ContentValues(); 
        args.put(CODICOES, codicoes); 
        args.put(CODIARTI, codiarti); 
        args.put(CODICOME, codicome); 
        args.put(DESDEFECHA, desdefecha); 
        args.put(HASTAFECHA, hastafecha); 
        args.put(PRECIO, precio); 

        return this.mDb.update(DATABASE_TABLE, args, CODICOES + "=" + codicoes, null) >0;  
    } 

    /** 
     * Create a new f_comesp from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public long createFromString(String[] linea){
    	NumberFormat nf   = NumberFormat.getInstance();
    	int    codicoes   = Integer.valueOf(linea[1]).intValue(); 
		String codiarti   = linea[2]; 
        String codicome   = linea[3];
        String desdefecha = linea[4];
        String hastafecha = linea[5];
        double precio     = 0;
        
    	try{
    		precio = nf.parse(linea[6]).doubleValue();
    	}catch(Exception e){
       	}
    	
    	return create(codicoes, codiarti, codicome, desdefecha, hastafecha, precio);
    }

    /** 
     * Update a new f_comesp from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public boolean updateFromString(String[] linea){

    	NumberFormat nf = NumberFormat.getInstance();
    	ContentValues args = new ContentValues(); 
    	double valor = 0;
    	 
    	Long   codicoes = Long.valueOf(linea[1]);
    	args.put(CODICOES, codicoes); 
    	
    	for (int i=2; i < (linea.length - 1); i = i+2) {

    		if ( linea[i].equalsIgnoreCase(PRECIO) ) { //es campo DOUBLE
    			try{
    				valor = nf.parse( linea[i+1] ).doubleValue();
    			}catch(Exception e){
    	       	}
    			args.put(linea[i], valor); 
    		}
    		else { //es campo string
    			args.put(linea[i], linea[i+1]); 
    		}

    	}
    	return this.mDb.update(DATABASE_TABLE, args, CODICOES + "=" + codicoes, null) >0;  
    }

    /** 
     * Delete f_comesp from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public void deleteFromString(String[] linea){
    	for (int i=1; i<linea.length; i++){
    		int codicoes = Integer.valueOf(linea[i]).intValue();
    		delete(codicoes);
    	}
    }
}
