package com.ventas.database;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;

public class FinciDBAdapter {
	public static final String CODIINCI = "_id"; 
    public static final String DESCINCI = "descinci"; 
    public static final String GRABA = "graba"; 
    public static final String FGRABA = "fgraba"; 

    public static final String DATABASE_TABLE = "f_inci"; 
 
    private SQLiteDatabase mDb; 
 
    /** 
     * Constructor - takes the SQLiteDatabase to access to the database
     *  
     * @param db 
     *            the SQLiteDatabase within which to work 
     */ 
    public FinciDBAdapter(SQLiteDatabase db) { 
        this.mDb = db; 
    } 

 
    /** 
     * Create a new f_inci. If the f_inci is successfully created return the new 
     * rowId for that f_inci, otherwise return a -1 to indicate failure. 
     *  
     * @param codiinci 
     * @param descinci 
     * @param graba 
     * @param fgraba 
     * @return rowId or -1 if failed 
     */ 
    public long create(String codiinci, String descinci, String graba, int fgraba){ 
        ContentValues initialValues = new ContentValues(); 
        initialValues.put(CODIINCI, codiinci); 
        initialValues.put(DESCINCI, descinci); 
        initialValues.put(GRABA, graba); 
        initialValues.put(FGRABA, fgraba); 
        return this.mDb.insert(DATABASE_TABLE, null, initialValues); 
    } 
 
    /** 
     * Delete the f_inci with the given rowId 
     *  
     * @param codiinci 
     * @return true if deleted, false otherwise 
     */ 
    public boolean delete(String codiinci) { 
 
        return this.mDb.delete(DATABASE_TABLE, CODIINCI + "= '" + codiinci + "'", null) > 0; 
    } 
 
    /** 
     * Return a Cursor over the list of all f_incis in the database 
     *  
     * @return Cursor over all f_incis 
     */ 
    public Cursor getAll() { 
 
        return this.mDb.query(DATABASE_TABLE, new String[] { CODIINCI, 
        		DESCINCI, GRABA, FGRABA }, null, null, null, null, null); 
    } 
 
    /** 
     * Return a Cursor positioned at the f_inci that matches the given rowId 
     * @param codiinci 
     * @return Cursor positioned to matching f_inci, if found 
     * @throws SQLException if f_inci could not be found/retrieved 
     */ 
    public Cursor get(String codiinci) throws SQLException { 
 
        Cursor mCursor = 
 
        this.mDb.query(true, DATABASE_TABLE, new String[] { CODIINCI, 
        		DESCINCI, GRABA, FGRABA }, CODIINCI + "= '" + codiinci + "'", null, null, null, null, null); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 
 

    /** 
     * Update the f_inci. 
     *  
     * @param codiinci 
     * @param descinci 
     * @param graba 
     * @param fgraba 
     * @return true if the note was successfully updated, false otherwise 
     */ 
    public boolean update(String codiinci, String descinci, String graba, int fgraba){ 
        ContentValues args = new ContentValues(); 
        args.put(CODIINCI, codiinci); 
        args.put(DESCINCI, descinci); 
        args.put(GRABA, graba); 
        args.put(FGRABA, fgraba); 
 
        return this.mDb.update(DATABASE_TABLE, args, CODIINCI + "= '" + codiinci + "'", null) >0;  
    } 

    /** 
     * Create a new f_inci from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public long createFromString(String[] linea){
    	String codiinci = linea[1];
    	String descinci = linea[2];
    	String graba    = linea[3];
    	int    fgrab    = 0;
    	
    	try{
    		fgrab = Integer.valueOf(linea[4]).intValue();
    	}catch(Exception e){
       	}
    	
    	return create(codiinci, descinci, graba, fgrab);
    }

    /** 
     * Update a new f_inci from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public boolean updateFromString(String[] linea){
    	
    	ContentValues args = new ContentValues(); 
    	
    	String codiinci = linea[1];
    	args.put(CODIINCI, codiinci); 
    	
    	for (int i=2; i < (linea.length - 1); i = i+2) {
    		
    		if ( linea[i].equalsIgnoreCase(FGRABA) ) { //es campo integer
    	    	try{
    	    		args.put(linea[i], Integer.valueOf(linea[i+1]).intValue() ); 
    	    	}catch(Exception e){
    	       	}
    		}
    		else { //es campo string
    			args.put(linea[i], linea[i+1]); 
    		}
    		
    	}
    	return this.mDb.update(DATABASE_TABLE, args, CODIINCI + "='" + codiinci + "'", null) >0;  
    }

    /** 
     * Delete f_inci from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public void deleteFromString(String[] linea){
    	for (int i=1; i<linea.length; i++){
    		delete(linea[i]);
    	}
    }
}
