package com.ventas.database;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;

public class FmenartDBAdapter {
	public static final String CODIMART    = "_id"; 
    public static final String DESCMART = "descmart";

    public static final String DATABASE_TABLE = "f_menart"; 
 
    private SQLiteDatabase mDb; 
 
    /** 
     * Constructor - takes the SQLiteDatabase to access to the database
     *  
     * @param db 
     *            the SQLiteDatabase within which to work 
     */ 
    public FmenartDBAdapter(SQLiteDatabase db) { 
        this.mDb = db; 
    } 
 
    /** 
     * Create a new f_menart. If the f_menart is successfully created return the new 
     * rowId for that f_menart, otherwise return a -1 to indicate failure. 
     *  
     * @param codimart 
     * @param descmart 
     * @return rowId or -1 if failed 
     */ 
    public long create(String codimart, String descmart){ 
        ContentValues initialValues = new ContentValues(); 
        initialValues.put(CODIMART, codimart); 
        initialValues.put(DESCMART, descmart); 
        return this.mDb.insert(DATABASE_TABLE, null, initialValues); 
    } 
 
    /** 
     * Delete the f_menart with the given rowId 
     *  
     * @param codimart 
     * @return true if deleted, false otherwise 
     */ 
    public boolean delete(String codimart) { 
 
        return this.mDb.delete(DATABASE_TABLE, CODIMART + "= '" + codimart + "'", null) > 0; 
    } 
 
    /** 
     * Return a Cursor over the list of all f_menarts in the database 
     *  
     * @return Cursor over all f_menarts 
     */ 
    public Cursor getAll() {
    	
    	Cursor mCursor = 
    			 
        this.mDb.query(DATABASE_TABLE, new String[] { CODIMART, 
        		DESCMART }, null, null, null, null, CODIMART);
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 
 
    /** 
     * Return a Cursor over the list of all f_menarts in the database 
     *  
     * @return Cursor over all f_menarts
     */ 
    public Cursor getAllConditional(String where) throws SQLException {
    	//Si la condicin est vaca, consultar sin condicin ya que ser ms rpido.
    	if (where == null || where.equals("")) {
    		return this.getAll();
    	}

    	try{
   	
	        //Si la condicin no es un cdigo, consultar sobre la descripcion
	    	return this.mDb.query(DATABASE_TABLE, new String[] { CODIMART, DESCMART}, 
	    			DESCMART + " like '%" + where+"%' or " + CODIMART  + " like '%" + where+"%'",
	        		null, null, null, DESCMART);
    	}
    	catch (SQLException e){
    		throw e;
    	}
    } 
    
    /** 
     * Return a Cursor positioned at the f_menart that matches the given rowId 
     * @param codimart 
     * @return Cursor positioned to matching f_menart, if found 
     * @throws SQLException if f_menart could not be found/retrieved 
     */ 
    public Cursor get(String codimart) throws SQLException { 
 
        Cursor mCursor = 
 
        this.mDb.query(true, DATABASE_TABLE, new String[] { CODIMART, 
        		DESCMART }, CODIMART + "= '" + codimart + "'", null, null, null, null, null); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 
 

    /** 
     * Update the f_menart. 
     *  
     * @param codicome 
     * @param desccome 
     * @return true if the note was successfully updated, false otherwise 
     */ 
    public boolean update(String codimart, String descmart){ 
        ContentValues args = new ContentValues(); 
        args.put(CODIMART, codimart); 
        args.put(DESCMART, descmart); 
 
        return this.mDb.update(DATABASE_TABLE, args, CODIMART + "= '" + codimart + "'", null) >0;  
    } 

    /** 
     * Create a new f_menart from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public long createFromString(String[] linea){
    	String codimart = linea[1];
    	String descmart = linea[2];
    	
    	return create(codimart, descmart);
    }

    /** 
     * Update a new f_menart from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public boolean updateFromString(String[] linea){
 	
    	ContentValues args = new ContentValues(); 
    	
    	String codimart = linea[1];
    	args.put(CODIMART, codimart); 
    	
    	for (int i=2; i < (linea.length - 1); i = i+2) {
    		args.put(linea[i], linea[i+1]); 
    	}
    	return this.mDb.update(DATABASE_TABLE, args, CODIMART + "='" + codimart + "'", null) >0;  
    }

    /** 
     * Delete f_menart from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public void deleteFromString(String[] linea){
    	for (int i=1; i<linea.length; i++){
    		delete(linea[i]);
    	}
    }
}
