package com.ventas.database;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;

public class FmencliDBAdapter {
	public static final String CODIMCLI    = "_id"; 
    public static final String DESCMCLI = "descmcli";

    public static final String DATABASE_TABLE = "f_mencli"; 
 
    private SQLiteDatabase mDb; 
 
    /** 
     * Constructor - takes the SQLiteDatabase to access to the database
     *  
     * @param db 
     *            the SQLiteDatabase within which to work 
     */ 
    public FmencliDBAdapter(SQLiteDatabase db) { 
        this.mDb = db; 
    } 
 
    /** 
     * Create a new f_mencli. If the f_mencli is successfully created return the new 
     * rowId for that f_mencli, otherwise return a -1 to indicate failure. 
     *  
     * @param codimcli 
     * @param descmcli 
     * @return rowId or -1 if failed 
     */ 
    public long create(String codimcli, String descmcli){ 
        ContentValues initialValues = new ContentValues(); 
        initialValues.put(CODIMCLI, codimcli); 
        initialValues.put(DESCMCLI, descmcli); 
        return this.mDb.insert(DATABASE_TABLE, null, initialValues); 
    } 
 
    /** 
     * Delete the f_mencli with the given rowId 
     *  
     * @param codimcli 
     * @return true if deleted, false otherwise 
     */ 
    public boolean delete(String codimcli) { 
 
        return this.mDb.delete(DATABASE_TABLE, CODIMCLI + "= '" + codimcli + "'", null) > 0; 
    } 
 
    /** 
     * Return a Cursor over the list of all f_menclis in the database 
     *  
     * @return Cursor over all f_menclis 
     */ 
    public Cursor getAll() { 
    	 
        Cursor mCursor = 
 
        this.mDb.query(DATABASE_TABLE, new String[] { CODIMCLI, 
        		DESCMCLI }, null, null, null, null, CODIMCLI); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 
    
    /** 
     * Return a Cursor over the list of all f_menclis in the database 
     *  
     * @return Cursor over all f_menclis
     */ 
    public Cursor getAllConditional(String where) throws SQLException {
    	//Si la condicin est vaca, consultar sin condicin ya que ser ms rpido.
    	if (where == null || where.equals("")) {
    		return this.getAll();
    	}

    	try{
   	
	        //Si la condicin no es un cdigo, consultar sobre la descripcion
	    	return this.mDb.query(DATABASE_TABLE, new String[] { CODIMCLI, DESCMCLI}, 
	    			DESCMCLI + " like '%" + where+"%' or " + CODIMCLI  + " like '%" + where+"%'",
	        		null, null, null, DESCMCLI);
    	}
    	catch (SQLException e){
    		throw e;
    	}
    } 
 
    /** 
     * Return a Cursor positioned at the f_mencli that matches the given rowId 
     * @param codimcli 
     * @return Cursor positioned to matching f_mencli, if found 
     * @throws SQLException if f_mencli could not be found/retrieved 
     */ 
    public Cursor get(String codimcli) throws SQLException { 
 
        Cursor mCursor = 
 
        this.mDb.query(true, DATABASE_TABLE, new String[] { CODIMCLI, 
        		DESCMCLI }, CODIMCLI + "= '" + codimcli + "'", null, null, null, null, null); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 
 

    /** 
     * Update the f_mencli. 
     *  
     * @param codimcli 
     * @param descmcli 
     * @return true if the note was successfully updated, false otherwise 
     */ 
    public boolean update(String codimcli, String descmcli){ 
        ContentValues args = new ContentValues(); 
        args.put(CODIMCLI, codimcli); 
        args.put(DESCMCLI, descmcli); 
 
        return this.mDb.update(DATABASE_TABLE, args, CODIMCLI + "= '" + codimcli + "'", null) >0;  
    } 

    /** 
     * Create a new f_mencli from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public long createFromString(String[] linea){
    	String codimcli = linea[1];
    	String descmcli = linea[2];
    	
    	return create(codimcli, descmcli);
    }

    /** 
     * Update a new f_mencli from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public boolean updateFromString(String[] linea){
    	
    	ContentValues args = new ContentValues(); 
    	
    	String codimcli = linea[1];
    	args.put(CODIMCLI, codimcli); 
    	
    	for (int i=2; i < (linea.length - 1); i = i+2) {
    		args.put(linea[i], linea[i+1]); 
    	}
    	return this.mDb.update(DATABASE_TABLE, args, CODIMCLI + "='" + codimcli + "'", null) >0;  
    	
    }

    /** 
     * Delete f_mencli from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public void deleteFromString(String[] linea){
    	for (int i=1; i<linea.length; i++){
    		delete(linea[i]);
    	}
    }
}
