package com.ventas.database;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;

public class FpevtcbDBAdapter {
	public static final String CODIPECB = "_id"; 
    public static final String FECHA    = "fecha";
    public static final String CODICLIE = "codiclie";
    public static final String CODIMCLI = "codimcli"; 
    public static final String TEXTMCLI = "textmcli";
    
    public static final String DATABASE_TABLE = "f_pevtcb"; 
 
    private SQLiteDatabase mDb; 
 
    /** 
     * Constructor - takes the SQLiteDatabase to access to the database
     *  
     * @param db 
     *            the SQLiteDatabase within which to work 
     */ 
    public FpevtcbDBAdapter(SQLiteDatabase db) { 
        this.mDb = db; 
    } 
 
    /** 
     * Create a new f_pevtcb. If the f_pevtcb is successfully created return the new 
     * rowId for that f_pevtcb, otherwise return a -1 to indicate failure. 
     *  
     * @param fecha 
     * @param codiclie 
     * @param codimcli 
     * @param textmcli 
     * @return rowId or -1 if failed 
     */ 
    public long create(String fecha, 
    						  long codiclie, 
    		                  String codimcli, 
    		                  String textmcli){ 
        ContentValues initialValues = new ContentValues(); 
        initialValues.put(FECHA, fecha); 
        initialValues.put(CODICLIE, codiclie); 
        initialValues.put(CODIMCLI, codimcli); 
        initialValues.put(TEXTMCLI, textmcli); 

        return this.mDb.insert(DATABASE_TABLE, null, initialValues); 
    } 
    
    /** 
     * Create a new f_pevtcb. If the f_pevtcb is successfully created return the new 
     * rowId for that f_pevtcb, otherwise return a -1 to indicate failure. 
     *  
     * @param codipecb 
     * @param fecha 
     * @param codiclie 
     * @param codimcli 
     * @param textmcli 
     * @return rowId or -1 if failed 
     */ 
    public long create(long codipecb, 
    						  String fecha, 
    						  long codiclie, 
    		                  String codimcli, 
    		                  String textmcli){ 
        ContentValues initialValues = new ContentValues(); 
        initialValues.put(CODIPECB, codipecb); 
        initialValues.put(FECHA, fecha); 
        initialValues.put(CODICLIE, codiclie); 
        initialValues.put(CODIMCLI, codimcli); 
        initialValues.put(TEXTMCLI, textmcli); 

        return this.mDb.insert(DATABASE_TABLE, null, initialValues); 
    } 

    
    /** 
     * Delete the f_pevtcb with the given rowId 
     *  
     * @param codipecb 
     * @return true if deleted, false otherwise 
     */ 
    public boolean delete(long codipecb) { 
 
        return this.mDb.delete(DATABASE_TABLE, CODIPECB + "=" + codipecb, null) > 0; 
    } 
 
    /** 
     * Return a Cursor over the list of all f_pevtcbs in the database 
     *  
     * @return Cursor over all f_pevtcbs
     */ 
    public Cursor getAll() { 
    	 
        Cursor mCursor = 
 
        this.mDb.query(DATABASE_TABLE, new String[] { CODIPECB, FECHA, 
        		CODICLIE, CODIMCLI, TEXTMCLI }, null, null, null, null, CODIPECB); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 
    
    /** 
     * Return a Cursor positioned at the f_pevtcb that matches the given rowId 
     * @param codipecb 
     * @return Cursor positioned to matching f_pevtcb, if found 
     * @throws SQLException if f_pevtcb could not be found/retrieved 
     */ 
    public Cursor get(int codipecb) throws SQLException { 
 
        Cursor mCursor = 
 
        this.mDb.query(true, DATABASE_TABLE, new String[] { CODIPECB, FECHA,
        		CODICLIE, CODIMCLI, TEXTMCLI }, CODIPECB + "=" + codipecb, null, null, null, null, null); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 
    
    /** 
     * Return a Cursor positioned at the f_pevtcb that matches the given rowId 
     * @param lcliente
     * @param fecha
     * @return Cursor positioned to matching f_pevtcb, if found 
     * @throws SQLException if f_pevtcb could not be found/retrieved 
     */ 
    public Cursor get(long lcliente, String fecha) throws SQLException { 
 
        Cursor mCursor = 
 
        this.mDb.query(true, DATABASE_TABLE, new String[] { CODIPECB, FECHA,
        		CODICLIE, CODIMCLI, TEXTMCLI }, CODICLIE + "=" + lcliente + " AND " + FECHA + " LIKE '" + fecha + "%'", 
        		null, null, null, null, null); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 

    /** 
     * Create a new fpevtcb from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public long createFromString(String[] linea){
    	String fecha = 		linea[1]; 
    	int    codipecb	= 	Integer.valueOf(linea[2]).intValue();
    	int codiclie = 		Integer.valueOf(linea[3]).intValue();
    	String codimcli = 	linea[4];
    	String textmcli = 	linea[5];
        
    	return create(codipecb, fecha, codiclie, codimcli, textmcli);
    }
    
    /** 
     * Update the f_pevtcb. 
     *  
     * @param codipecb 
     * @param fecha
     * @param codiclie 
     * @param codimcli 
     * @param textmcli 
     * @param precio 
     * @param comision 
     * @return true if the note was successfully updated, false otherwise 
     */ 
    public boolean update(long codipecb, 
              String fecha, 
			  long codiclie, 
              String codimcli, 
              String textmcli){ 
        ContentValues args = new ContentValues(); 
        args.put(CODIPECB, codipecb); 
        args.put(FECHA, fecha); 
        args.put(CODICLIE, codiclie); 
        args.put(CODIMCLI, codimcli); 
        args.put(TEXTMCLI, textmcli); 

        return this.mDb.update(DATABASE_TABLE, args, CODIPECB + "=" + codipecb, null) >0;  
    } 

}
