package com.ventas.database;

import java.text.NumberFormat;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;

public class FpevtlnDBAdapter {
	public static final String CODIPELN = "_id"; 
    public static final String CODIPECB = "codipecb";
    public static final String CODIARTI = "codiarti"; 
    public static final String CODIMART = "codimart"; 
    public static final String CODITIPF = "coditipf";
    public static final String CANTIDAD = "cantidad";
    public static final String PRECIO = "precio";
    public static final String TEXTMART = "textmart";
    public static final String CODIUNID = "codiunid";
    public static final String DESCARTI = "descarti";
    public static final String TIPOPRECIO = "tipoprecio";
    public static final String CODIGOBARRAS = "codigobarras";
    public static final String CANTTOTA = "canttota";
    
    public static final String DATABASE_TABLE = "f_pevtln"; 
 
    private SQLiteDatabase mDb; 
 
    /** 
     * Constructor - takes the SQLiteDatabase to access to the database
     *  
     * @param db 
     *            the SQLiteDatabase within which to work 
     */ 
    public FpevtlnDBAdapter(SQLiteDatabase db) { 
        this.mDb = db; 
    } 
 
    /** 
     * Create a new f_pevtln. If the f_pevtln is successfully created return the new 
     * rowId for that f_pevtln, otherwise return a -1 to indicate failure. 
     *  
     * @param codipeln 
     * @param codipecb 
     * @param codiarti 
     * @param codimart 
     * @param coditipf 
     * @param cantidad 
     * @param precio 
     * @param textmart 
     * @param codiunid 
     * @param descarti 
     * @param tipoprecio 
     * @param codigobarras 
     * @param canttota 
     * @return rowId or -1 if failed 
     */ 
    public long create(int codipeln, 
    						  int codipecb, 
    		                  String codiarti, 
    		                  String codimart, 
    		                  double cantidad, 
    		                  double precio, 
    		                  String textmart, 
    		                  String codiunid, 
    		                  String descarti,
    		                  String tipoprecio,
    		                  String codigobarras,
    		                  double canttota){ 
        ContentValues initialValues = new ContentValues(); 
        initialValues.put(CODIPELN, codipeln); 
        initialValues.put(CODIPECB, codipecb); 
        initialValues.put(CODIARTI, codiarti); 
        initialValues.put(CODIMART, codimart); 
        initialValues.put(CANTIDAD, cantidad); 
        initialValues.put(PRECIO, precio); 
        initialValues.put(TEXTMART, textmart); 
        initialValues.put(CODIUNID, codiunid); 
        initialValues.put(DESCARTI, descarti); 
        initialValues.put(TIPOPRECIO, tipoprecio); 
        initialValues.put(CODIGOBARRAS, codigobarras); 
        initialValues.put(CANTTOTA, canttota); 

        return this.mDb.insert(DATABASE_TABLE, null, initialValues); 
    } 

    /** 
     * Create a new f_pevtln. If the f_pevtln is successfully created return the new 
     * rowId for that f_pevtln, otherwise return a -1 to indicate failure. 
     *  
     * @param codipecb 
     * @param codiarti 
     * @param codimart 
     * @param coditipf 
     * @param cantidad 
     * @param precio 
     * @param textmart 
     * @param codiunid 
     * @param descarti 
     * @param tipoprecio 
     * @param codigobarras 
     * @param canttota 
     * @return rowId or -1 if failed 
     */ 
    public long create(long codipecb, 
    		                  String codiarti, 
    		                  String codimart, 
    		                  double cantidad, 
    		                  double precio, 
    		                  String textmart, 
    		                  String codiunid, 
    		                  String descarti,
    		                  String tipoprecio,
    		                  String codigobarras,
    		                  double canttota){ 
        ContentValues initialValues = new ContentValues(); 
        initialValues.put(CODIPECB, codipecb); 
        initialValues.put(CODIARTI, codiarti); 
        initialValues.put(CODIMART, codimart); 
        initialValues.put(CANTIDAD, cantidad); 
        initialValues.put(PRECIO, precio); 
        initialValues.put(TEXTMART, textmart); 
        initialValues.put(CODIUNID, codiunid); 
        initialValues.put(DESCARTI, descarti); 
        initialValues.put(TIPOPRECIO, tipoprecio); 
        initialValues.put(CODIGOBARRAS, codigobarras); 
        initialValues.put(CANTTOTA, canttota); 

        return this.mDb.insert(DATABASE_TABLE, null, initialValues); 
    } 
    
    /** 
     * Delete the f_pevtln with the given rowId 
     *  
     * @param codipeln 
     * @return true if deleted, false otherwise 
     */ 
    public boolean delete(long codipeln) { 
 
        return this.mDb.delete(DATABASE_TABLE, CODIPELN + "=" + codipeln, null) > 0; 
    } 
    
    /** 
     * Delete the f_pevtln with the given codipecb 
     *  
     * @param codipecb 
     * @return true if deleted, false otherwise 
     */ 
    public boolean deleteByFpevtcb(long codipecb) { 
 
        return this.mDb.delete(DATABASE_TABLE, CODIPECB + "=" + codipecb, null) > 0; 
    } 
 
    /** 
     * Return a Cursor over the list of all f_pevtlns in the database 
     *  
     * @return Cursor over all f_pevtlns
     */ 
    public Cursor getAll() {
    	
    	Cursor mCursor = 
    			 
        this.mDb.query(DATABASE_TABLE, new String[] { CODIPELN, 
        		CODIPECB, CODIARTI, CODIMART, CODITIPF, CANTIDAD, PRECIO,
        		TEXTMART, CODIUNID, DESCARTI, TIPOPRECIO, CODIGOBARRAS, CANTTOTA }, null, null, null, null, CODIPELN); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
} 
 
    /** 
     * Return a Cursor positioned at the f_pevtln that matches the given rowId 
     * @param codipeln 
     * @return Cursor positioned to matching f_pevtln, if found 
     * @throws SQLException if f_pevtln could not be found/retrieved 
     */ 
    public Cursor get(long codipeln) throws SQLException { 
 
        Cursor mCursor = 
 
        this.mDb.query(true, DATABASE_TABLE, new String[] { CODIPELN, 
        		CODIPECB, CODIARTI, CODIMART, CODITIPF, CANTIDAD, PRECIO,
        		TEXTMART, CODIUNID, DESCARTI, TIPOPRECIO, CODIGOBARRAS, CANTTOTA }, CODIPELN + "=" + codipeln, null, null, null, CODIPELN, null); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 

    //Cursor de Lineas
	public Cursor getAllLinArt(long codipecb) throws SQLException { 
    	
    	String selectQuery = "SELECT f_pevtln._id," + 
    								"f_pevtln.codipecb," + 
    								"f_pevtln.codiarti," + 
    								"f_pevtln.codimart," + 
    								"f_pevtln.coditipf," + 
    								"f_pevtln.cantidad," + 
    								"f_pevtln.precio,"+
    								"f_pevtln.textmart,"+
    								"f_pevtln.codiunid," + 
    								"f_pevtln.tipoprecio,"+
    								"f_pevtln.codigobarras,"+
    								"f_pevtln.canttota," + 
    								"articulo.descarti " + 
    						"FROM f_pevtln, articulo " +
    						"WHERE articulo._id = f_pevtln.codiarti "+
    						"AND f_pevtln.codipecb=" + codipecb; 
    	
        Cursor mCursor = this.mDb.rawQuery(selectQuery, null) ;
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 

    //Cursor de una linea
	public Cursor getLinArt(long codipeln) throws SQLException { 
    	
    	String selectQuery = "SELECT f_pevtln._id," + 
    								"f_pevtln.codipecb," + 
    								"f_pevtln.codiarti," + 
    								"f_pevtln.codimart," + 
    								"f_pevtln.coditipf," + 
    								"f_pevtln.cantidad," + 
    								"f_pevtln.precio,"+
    								"f_pevtln.textmart,"+
    								"f_pevtln.codiunid," + 
    								"f_pevtln.tipoprecio,"+
    								"f_pevtln.codigobarras,"+
    								"f_pevtln.canttota," + 
    								"articulo.descarti " + 
    						"FROM f_pevtln, articulo " +
    						"WHERE articulo._id = f_pevtln.codiarti "+
    						"AND f_pevtln._id=" + codipeln; 
    	
        Cursor mCursor = this.mDb.rawQuery(selectQuery, null) ;
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 

    /** 
     * Return a Cursor positioned at the f_pevtln that matches the given rowId 
     * @param codipeln 
     * @return Cursor positioned to matching f_pevtln, if found 
     * @throws SQLException if f_pevtln could not be found/retrieved 
     */ 
    public Cursor getByFpevtcb(long codipecb) throws SQLException { 
 
        Cursor mCursor = 
 
        this.mDb.query(true, DATABASE_TABLE, new String[] { CODIPELN, 
        		CODIPECB, CODIARTI, CODIMART, CODITIPF, CANTIDAD, PRECIO,
        		TEXTMART, CODIUNID, DESCARTI, TIPOPRECIO, CODIGOBARRAS, CANTTOTA }, CODIPECB + "=" + codipecb, null, null, null, CODIPELN, null); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 

    /** 
     * Create a new fpevtln from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public long createFromString(String[] linea){
    	NumberFormat nf = NumberFormat.getInstance();
    	
    	int codipeln	= 		Integer.valueOf(linea[1]).intValue();
    	int codipecb = 			Integer.valueOf(linea[2]).intValue(); 
    	String codiarti =		linea[3];
    	String codimart = 		linea[4];
    	double cantidad = 0;
        double precio = 0;
        String textmart = 		linea[8];
        String codiunid = 		linea[9];
        String descarti = 		"";
        String tipoprecio =		linea[10];
        String codigobarras = 	linea[11];
        double canttota = 0;
        
    	try{
    		cantidad = nf.parse(linea[6]).doubleValue();
    	}catch(Exception e){
       	}
    	try{
    		precio = nf.parse(linea[7]).doubleValue();
    	}catch(Exception e){
       	}
    	try{
    		//canttota = nf.parse(linea[13]).doubleValue();
    		canttota = nf.parse(linea[12]).doubleValue();
    	}catch(Exception e){
       	}
        
    	return create(codipeln, codipecb, codiarti, codimart, cantidad, precio, textmart, codiunid, descarti, tipoprecio, codigobarras, canttota);
    }
    
    /** 
     * Update the f_pevtln. 
     *  
     * @param codipeln 
     * @param codipecb 
     * @param codiarti 
     * @param codimart 
     * @param coditipf 
     * @param cantidad 
     * @param precio 
     * @param textmart 
     * @param codiunid 
     * @param descarti 
     * @param tipoprecio 
     * @param codigobarras 
     * @param canttota 
     * @return true if the note was successfully updated, false otherwise 
     */ 
    public boolean update(long codipeln, 
			  long codipecb, 
              String codiarti, 
              String codimart, 
              double cantidad, 
              double precio, 
              String textmart, 
              String codiunid, 
              String descarti,
              String tipoprecio,
              String codigobarras,
              double canttota){ 
        ContentValues args = new ContentValues(); 
        args.put(CODIARTI, codiarti); 
        args.put(CODIMART, codimart); 
        args.put(CANTIDAD, cantidad); 
        args.put(PRECIO, precio); 
        args.put(TEXTMART, textmart); 
        args.put(CODIUNID, codiunid); 
        args.put(DESCARTI, descarti); 
        args.put(TIPOPRECIO, tipoprecio); 
        args.put(CODIGOBARRAS, codigobarras); 
        args.put(CANTTOTA, canttota); 

        return this.mDb.update(DATABASE_TABLE, args, CODIPELN + "=" + codipeln, null) >0;  
    } 

}
