package com.ventas.database;

import java.text.NumberFormat;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;

public class FpreminimoDBAdapter {
	public static final String CODIPRMI = "_id"; 
    public static final String CODIARTI = "codiarti";
    public static final String DESDE = "desde";
    public static final String HASTA = "hasta";
    public static final String MINIMO = "minimo";
    
    public static final String DATABASE_TABLE = "f_preminimo"; 
 
    private SQLiteDatabase mDb; 
 
    /** 
     * Constructor - takes the SQLiteDatabase to access to the database
     *  
     * @param db 
     *            the SQLiteDatabase within which to work 
     */ 
    public FpreminimoDBAdapter(SQLiteDatabase db) { 
        this.mDb = db; 
    } 
 
    /** 
     * Create a new f_preminimo. If the f_preminimo is successfully created return the new 
     * rowId for that f_preminimo, otherwise return a -1 to indicate failure. 
     *  
     * @param codiprmi 
     * @param codiarti 
     * @param desde 
     * @param hasta 
     * @param minimo 
     * @return rowId or -1 if failed 
     */ 
    public long create(int codiprmi, 
							  String codiarti, 
				              String desde, 
				              String hasta, 
				              double minimo){ 
        ContentValues initialValues = new ContentValues(); 
        initialValues.put(CODIPRMI, codiprmi); 
        initialValues.put(CODIARTI, codiarti); 
        initialValues.put(DESDE, desde); 
        initialValues.put(HASTA, hasta); 
        initialValues.put(MINIMO, minimo); 

        return this.mDb.insert(DATABASE_TABLE, null, initialValues); 
    } 

    
    /** 
     * Delete the f_preminimo with the given rowId 
     *  
     * @param codiprmi 
     * @return true if deleted, false otherwise 
     */ 
    public boolean delete(int codiprmi) { 
 
        return this.mDb.delete(DATABASE_TABLE, CODIPRMI + "=" + codiprmi, null) > 0; 
    } 
 
    /** 
     * Return a Cursor over the list of all f_preminimos in the database 
     *  
     * @return Cursor over all f_preminimos
     */ 
    public Cursor getAll() { 
        return this.mDb.query(DATABASE_TABLE, new String[] { CODIPRMI, 
        		CODIARTI, DESDE, HASTA, MINIMO }, null, null, null, null, null); 
} 
 
    /** 
     * Return a Cursor positioned at the f_preminimo that matches the given rowId 
     * @param codiprmi 
     * @return Cursor positioned to matching f_preminimo, if found 
     * @throws SQLException if f_preminimo could not be found/retrieved 
     */ 
    public Cursor get(int codiprmi) throws SQLException { 
 
        Cursor mCursor = 
 
        this.mDb.query(true, DATABASE_TABLE, new String[] { CODIPRMI, 
        		CODIARTI, DESDE, HASTA, MINIMO }, CODIPRMI + "=" + codiprmi, null, null, null, null, null); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 


    /** 
     * Return a Cursor positioned at the f_clesp that matches the given rowId 
     * @param codicles 
     * @return Cursor positioned to matching f_clesp, if found 
     * @throws SQLException if f_clesp could not be found/retrieved 
     */ 
    public Cursor get(String vigencia, String articulo) throws SQLException { 
        Cursor mCursor = this.mDb.query(DATABASE_TABLE, new String[] { CODIPRMI, 
        		CODIARTI, DESDE, HASTA, MINIMO }, CODIARTI + "= '" + articulo + "'" + 
        		  " AND (" + HASTA + ">= '" + vigencia + "' OR " + HASTA + " = '')", null, null, null, DESDE); 

        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 


    /** 
     * Update the f_preminimo. 
     *  
     * @param codiprmi 
     * @param codiarti 
     * @param desde 
     * @param hasta 
     * @param minimo 
     * @return true if the note was successfully updated, false otherwise 
     */ 
    public boolean update(int codiprmi, 
	  					  String codiarti, 
			              String desde, 
			              String hasta, 
			              double minimo){ 
        ContentValues args = new ContentValues(); 
        args.put(CODIPRMI, codiprmi); 
        args.put(CODIARTI, codiarti); 
        args.put(DESDE, desde); 
        args.put(HASTA, hasta); 
        args.put(MINIMO, minimo); 

        return this.mDb.update(DATABASE_TABLE, args, CODIPRMI + "=" + codiprmi, null) >0;  
    } 

    /** 
     * Create a new f_preminimo from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public long createFromString(String[] linea){
    	NumberFormat nf = NumberFormat.getInstance();
    	int codiprmi    = Integer.valueOf(linea[1]).intValue(); 
		String codiarti = linea[2]; 
        String desde    = linea[3]; 
        String hasta    = linea[4]; 
        double minimo   = 0;
        
    	try{
    		minimo = nf.parse(linea[5]).doubleValue();
    	}catch(Exception e){
       	}
    	
    	return create(codiprmi, codiarti, desde, hasta, minimo);
    }

    /** 
     * Update a new f_preminimo from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public boolean updateFromString(String[] linea){

    	NumberFormat nf = NumberFormat.getInstance();
    	ContentValues args = new ContentValues(); 
    	double valor = 0;
    	 
    	Long   codiprmi = Long.valueOf(linea[1]);
    	args.put(CODIPRMI, codiprmi); 
    	
    	for (int i=2; i < (linea.length - 1); i = i+2) {

    		if ( linea[i].equalsIgnoreCase(MINIMO) ) { //es campo DOUBLE
    			try{
    				valor = nf.parse( linea[i+1] ).doubleValue();
    			}catch(Exception e){
    	       	}
    			args.put(linea[i], valor); 
    		}
    		else { //es campo string
    			args.put(linea[i], linea[i+1]); 
    		}

    	}
    	return this.mDb.update(DATABASE_TABLE, args, CODIPRMI + "=" + codiprmi, null) >0;  
    }

    /** 
     * Delete f_preminimo from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public void deleteFromString(String[] linea){
    	for (int i=1; i<linea.length; i++){
    		int codiprmi = Integer.valueOf(linea[i]).intValue();
    		delete(codiprmi);
    	}
    }
}
