package com.ventas.database;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;

public class ProvinciDBAdapter {
	public static final String CODIPROV    = "_id"; 
    public static final String DESCRIPCION = "descripcion";

    public static final String DATABASE_TABLE = "provinci"; 
 
    private SQLiteDatabase mDb; 
 
    /** 
     * Constructor - takes the SQLiteDatabase to access to the database
     *  
     * @param db 
     *            the SQLiteDatabase within which to work 
     */ 
    public ProvinciDBAdapter(SQLiteDatabase db) { 
        this.mDb = db; 
    } 
 
 
    /** 
     * Create a new provinci. If the provinci is successfully created return the new 
     * rowId for that provinci, otherwise return a -1 to indicate failure. 
     *  
     * @param codiprov 
     * @param descripcion 
     * @return rowId or -1 if failed 
     */ 
    public long create(String codiprov, String descripcion){ 
        ContentValues initialValues = new ContentValues(); 
        initialValues.put(CODIPROV, codiprov); 
        initialValues.put(DESCRIPCION, descripcion); 
        return this.mDb.insert(DATABASE_TABLE, null, initialValues); 
    } 
 
    /** 
     * Delete the provinci with the given rowId 
     *  
     * @param codiprov 
     * @return true if deleted, false otherwise 
     */ 
    public boolean delete(String codiprov) { 
 
        return this.mDb.delete(DATABASE_TABLE, CODIPROV + "= '" + codiprov + "'", null) > 0; 
    } 
 
    /** 
     * Return a Cursor over the list of all provincis in the database 
     *  
     * @return Cursor over all provincis 
     */ 
    public Cursor getAll() { 
 
        return this.mDb.query(DATABASE_TABLE, new String[] { CODIPROV, 
        		DESCRIPCION }, null, null, null, null, null); 
    } 
 
    /** 
     * Return a Cursor positioned at the provinci that matches the given rowId 
     * @param codiprov 
     * @return Cursor positioned to matching provinci, if found 
     * @throws SQLException if provinci could not be found/retrieved 
     */ 
    public Cursor get(String codiprov) throws SQLException { 
 
        Cursor mCursor = 
 
        this.mDb.query(true, DATABASE_TABLE, new String[] { CODIPROV, 
        		DESCRIPCION }, CODIPROV + "= '" + codiprov + "'", null, null, null, null, null); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 
 

    /** 
     * Update the provinci. 
     *  
     * @param codiprov 
     * @param descripcion 
     * @return true if the note was successfully updated, false otherwise 
     */ 
    public boolean update(String codiprov, String descripcion){ 
        ContentValues args = new ContentValues(); 
        args.put(CODIPROV, codiprov); 
        args.put(DESCRIPCION, descripcion); 
 
        return this.mDb.update(DATABASE_TABLE, args, CODIPROV + "= '" + codiprov + "'", null) >0;  
    } 

    /** 
     * Create a new provinci from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public long createFromString(String[] linea){
    	String codiprov    = linea[1];
    	String descripcion = linea[2];
    	
    	return create(codiprov, descripcion);
    }

    /** 
     * Update a new provinci from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public boolean updateFromString(String[] linea){

    	ContentValues args = new ContentValues(); 
    	
    	String codiprov    = linea[1];
    	args.put(CODIPROV, codiprov); 
    	
    	for (int i=2; i < (linea.length - 1); i = i+2) {
    		args.put(linea[i], linea[i+1]); 
    	}
    	return this.mDb.update(DATABASE_TABLE, args, CODIPROV + "='" + codiprov + "'", null) >0;  
    }
    
    /** 
     * Delete provinci from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public void deleteFromString(String[] linea){
    	for (int i=1; i<linea.length; i++){
    		delete(linea[i]);
    	}
    }
}
