package com.ventas.database;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;

public class UnidadDBAdapter {
	public static final String CODIUNID    = "_id"; 
    public static final String DESCUNID = "descunid";

    public static final String DATABASE_TABLE = "unidad"; 
 
    private SQLiteDatabase mDb; 
 
    /** 
     * Constructor - takes the SQLiteDatabase to access to the database
     *  
     * @param db 
     *            the SQLiteDatabase within which to work 
     */ 
    public UnidadDBAdapter(SQLiteDatabase db) { 
        this.mDb = db; 
    } 
 
 
    /** 
     * Create a new unidad. If the unidad is successfully created return the new 
     * rowId for that unidad, otherwise return a -1 to indicate failure. 
     *  
     * @param codiunid 
     * @param descunid 
     * @return rowId or -1 if failed 
     */ 
    public long create(String codiunid, String descunid){ 
        ContentValues initialValues = new ContentValues(); 
        initialValues.put(CODIUNID, codiunid); 
        initialValues.put(DESCUNID, descunid); 
        return this.mDb.insert(DATABASE_TABLE, null, initialValues); 
    } 
 
    /** 
     * Delete the unidad with the given rowId 
     *  
     * @param codiunid 
     * @return true if deleted, false otherwise 
     */ 
    public boolean delete(String codiunid) { 
 
        return this.mDb.delete(DATABASE_TABLE, CODIUNID + "= '" + codiunid + "'", null) > 0; 
    } 
 
    /** 
     * Return a Cursor over the list of all unidads in the database 
     *  
     * @return Cursor over all unidads 
     */ 
    public Cursor getAll() { 
 
        return this.mDb.query(DATABASE_TABLE, new String[] { CODIUNID, 
        		DESCUNID }, null, null, null, null, DESCUNID + " DESC"); 
    } 
 
    /** 
     * Return a Cursor positioned at the unidad that matches the given rowId 
     * @param codiunid 
     * @return Cursor positioned to matching unidad, if found 
     * @throws SQLException if unidad could not be found/retrieved 
     */ 
    public Cursor get(String codiunid) throws SQLException { 
 
        Cursor mCursor = 
 
        this.mDb.query(true, DATABASE_TABLE, new String[] { CODIUNID, 
        		DESCUNID }, CODIUNID + "= '" + codiunid + "'", null, null, null, null, null); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 
 

    /** 
     * Update the unidad. 
     *  
     * @param codiunid 
     * @param descunid 
     * @return true if the note was successfully updated, false otherwise 
     */ 
    public boolean update(String codiunid, String descunid){ 
        ContentValues args = new ContentValues(); 
        args.put(CODIUNID, codiunid); 
        args.put(DESCUNID, descunid); 
 
        return this.mDb.update(DATABASE_TABLE, args, CODIUNID + "= '" + codiunid + "'", null) >0;  
    } 

    /** 
     * Create a new unidad from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public long createFromString(String[] linea){
    	String codiunid = linea[1];
    	String descunid = linea[2];
    	
    	return create(codiunid, descunid);
    }

    /** 
     * Update a new unidad from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public boolean updateFromString(String[] linea){

    	ContentValues args = new ContentValues(); 
    	
    	String codiunid    = linea[1];
    	args.put(CODIUNID, codiunid); 
    	
    	for (int i=2; i < (linea.length - 1); i = i+2) {
    		args.put(linea[i], linea[i+1]); 
    	}
    	return this.mDb.update(DATABASE_TABLE, args, CODIUNID + "='" + codiunid + "'", null) >0;  
    }

    /** 
     * Delete unidad from a string separated with pipe 
     *  
     * @param linea 
     * @return rowId or -1 if failed 
     */ 
    public void deleteFromString(String[] linea){
    	for (int i=1; i<linea.length; i++){
    		delete(linea[i]);
    	}
    }
}
