package com.ventas.database;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;

public class UprecioDBAdapter {
    public static final String DATABASE_TABLE = "uprecio"; 
 
    public static final String CODIUPRE = "_id";
    public static final String CODICLIE = "codiclie";
    public static final String CODIARTI = "codiarti"; 
    public static final String PRECIO 	= "precio"; 

    private SQLiteDatabase mDb; 
    
    /** 
     * Constructor - takes the SQLiteDatabase to access to the database
     *  
     * @param db 
     *            the SQLiteDatabase within which to work 
     */ 
    public UprecioDBAdapter(SQLiteDatabase db) { 
        this.mDb = db; 
    } 
    
    /** 
     * Create a new uprecio. If the uprecio is successfully created return the new 
     * rowId for that uprecio, otherwise return a -1 to indicate failure. 
     *  
     * @param codiupre
     * @param codiclie 
     * @param codiarti
     * @param precio 
     */ 
    public long create(long codiupre, 
    						long codiclie, 
    		                String codiarti, 
    		                double precio){ 
        ContentValues initialValues = new ContentValues(); 
        initialValues.put(CODIUPRE, codiupre); 
        initialValues.put(CODICLIE, codiclie); 
        initialValues.put(CODIARTI, codiarti); 
        initialValues.put(PRECIO, precio); 
        
        return this.mDb.insert(DATABASE_TABLE, null, initialValues); 
    } 
    
    /** 
     * Create a new uprecio. If the uprecio is successfully created return the new 
     * rowId for that uprecio, otherwise return a -1 to indicate failure. 
     *  
     * @param codiclie 
     * @param codiarti
     * @param precio 
     */ 
    public long create(long codiclie, 
    		                String codiarti, 
    		                double precio){ 
        ContentValues initialValues = new ContentValues();  
        initialValues.put(CODICLIE, codiclie); 
        initialValues.put(CODIARTI, codiarti); 
        initialValues.put(PRECIO, precio); 
        
        return this.mDb.insert(DATABASE_TABLE, null, initialValues); 
    } 
       
    /** 
     * Delete the uprecio with the given rowId 
     *  
     * @param id 
     * @return true if deleted, false otherwise 
     */ 
    public boolean delete(long codiupre) { 
 
        return this.mDb.delete(DATABASE_TABLE, CODIUPRE + "=" + codiupre, null) > 0; 
    } 
    
    /** 
     * Delete the uprecio with the given codiclie, codiarti 
     *  
     * @param codiclie
     * @param codiarti
     * @return true if deleted, false otherwise 
     */ 
    public boolean delete(long codiclie, 
            			String codiarti) { 
 
        return this.mDb.delete(DATABASE_TABLE, CODICLIE + "=" + codiclie + " AND " + CODIARTI + "='" + codiarti + "'", null) > 0; 
    } 
 
    /** 
     * Return a Cursor over the list of all uprecio in the database 
     *  
     * @return Cursor over all uprecio
     */ 
    public Cursor getAll() { 
    	Cursor mCursor =  
    	this.mDb.query(DATABASE_TABLE, new String[] { CODIUPRE,
    			CODICLIE, CODIARTI, PRECIO }, null, null, null, null, CODIUPRE);
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 
    
    /** 
     * Return a Cursor positioned at the uprecio that matches the given rowId 
     * @param codiupre 
     * @return Cursor positioned to matching f_pevtln, if found 
     * @throws SQLException if uprecio could not be found/retrieved 
     */ 
    public Cursor get(long codiupre) throws SQLException { 
 
        Cursor mCursor = 
 
        this.mDb.query(true, DATABASE_TABLE, new String[] { CODIUPRE, 
        		CODICLIE, CODIARTI, PRECIO }, CODIUPRE + "=" + codiupre, null, null, null, null, null); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 
    
    /** 
     * Return a Cursor positioned at the uprecio that matches the given codiclie, codiarti
     * @param codiclie
     * @param codiarti
     * @return Cursor positioned to matching uprecio, if found 
     * @throws SQLException if uprecio could not be found/retrieved 
     */ 
    public Cursor get(long codiclie, 
						String codiarti) throws SQLException { 
 
        Cursor mCursor =  
        this.mDb.query(true, DATABASE_TABLE, new String[] { CODIUPRE, 
        		CODICLIE, CODIARTI, PRECIO }, CODICLIE + "=" + codiclie + " AND " + CODIARTI + "='" + codiarti + "'", null, null, null, null, null); 
        if (mCursor != null) { 
            mCursor.moveToFirst(); 
        } 
        return mCursor; 
    } 
    
    /** 
     * Update the uprecio. 
     *  
     * @param codiupre
     * @param codiclie
     * @param codiarti 
     * @param precio
     * @return true if the note was successfully updated, false otherwise 
     */ 
    public boolean update(long codiupre, 
    						long codiclie, 
            				String codiarti, 
            				double precio){ 
        ContentValues args = new ContentValues(); 
        args.put(CODIUPRE, codiupre); 
        args.put(CODICLIE, codiclie); 
        args.put(CODIARTI, codiarti); 
        args.put(PRECIO, precio); 
        return this.mDb.update(DATABASE_TABLE, args, CODIUPRE + "=" + codiupre, null) >0;  
    } 
    
    /** 
     * Update the uprecio. 
     *  
     * @param codiclie
     * @param codiarti 
     * @param precio
     * @return true if the note was successfully updated, false otherwise 
     */ 
    public boolean update(long codiclie, 
            				String codiarti, 
            				double precio){ 
        ContentValues args = new ContentValues(); 
        args.put(CODICLIE, codiclie); 
        args.put(CODIARTI, codiarti); 
        args.put(PRECIO, precio); 
        return this.mDb.update(DATABASE_TABLE, args, CODICLIE + "=" + codiclie + " AND " + CODIARTI + "='" + codiarti + "'", null) >0;  
    } 

}
