package com.ventas.pedidoscomercial;

import com.ventas.database.ArticuloDBAdapter;
import com.ventas.database.DBAdapter;
import android.os.Bundle;
import android.text.Editable;
import android.text.InputType;
import android.text.TextWatcher;
import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.database.Cursor;
import android.view.View;
import android.view.WindowManager;
import android.widget.AdapterView;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.SimpleCursorAdapter;
import android.widget.TextView;
import android.widget.TwoLineListItem;

/**
 * Muestra una lista de todos los articulos cargados en la base de datos del terminal.
 * Permite introducir un filtro de bsqueda en el campo de texto situado en la parte
 * superior de la pantalla, de manera que si el usuario introduce un nmero, buscar
 * el articulo con dicho cdigo; si intruduce una cadena de texto, buscar en funcin
 * del nombre del articulo.
 */
public class ArticuloListActivity extends Activity {
	private String    mPermite_navegacion;
	private DBAdapter mDbHelper;
	private EditText  mSearchArticuloText;
	private ListView  mArticulos;  
	private String    mCodiartiResult = ""; //Resultado en bsquedas

    
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.two_columns_list);

        // Get the message from the intent
        Intent intent = getIntent();
        mPermite_navegacion = intent.getStringExtra("PERMITE_NAVEGACION");

        mSearchArticuloText = (EditText) findViewById(R.id.search); 
        mArticulos = (ListView) findViewById(R.id.mlist); 
        registerForContextMenu(mArticulos);  //Registers a context menu to be shown for the given view

        try{
	        mDbHelper = new DBAdapter(this);
	        mDbHelper.open();
        }
        catch (Exception e){
        	msboxFinish("Error en el acceso a los datos.");
        	return;
        }
        

        //Rellenar con todos los articulos de la base de datos
        fillData();

        //Eventos sobre el campo de texto para detectar la introduccin de texto
        //y filtrar los articulos.
        mSearchArticuloText.addTextChangedListener(new TextWatcher() { 
            public void onTextChanged(CharSequence s, int start, int before, int count){ 
                fillData();
            } 
        
            public void beforeTextChanged(CharSequence s, int start, int count, int after){ 
            } 
        
            public void afterTextChanged(Editable s){
            } 
        }); 

        mArticulos.setOnItemClickListener(new ListView.OnItemClickListener(){

	    	   public void onItemClick(AdapterView<?> adapter, View view, int position, long id) {
	    		    //protected void onListItemClick(ListView l, View v, int position, long id) {
	    		        //super.onListItemClick(l, view, position, id);
	    	        TextView label1 = ((TwoLineListItem) view).getText1();
	    	        
	    	    	if (mPermite_navegacion.equalsIgnoreCase("SI")){
	    		        verPrecios(label1.getText().toString());
	    	    	} else{
	    	    		mCodiartiResult = label1.getText().toString();
	    	    		finish();
	    	    	}
	    	   }
	    });

		getWindow().setSoftInputMode(WindowManager.LayoutParams.SOFT_INPUT_STATE_HIDDEN);
    }

    public void onDestroy() {
    	super.onDestroy();

    	mDbHelper.close();
    }


    public void msboxFinish(String str) 
    { 
        AlertDialog.Builder dlgAlert  = new AlertDialog.Builder(this);                       
        dlgAlert.setMessage(str);  
        dlgAlert.setPositiveButton("Aceptar",new DialogInterface.OnClickListener() { 
            public void onClick(DialogInterface dialog, int whichButton) {
                finish();  
            } 
       }); 

        dlgAlert.setCancelable(true); 
        dlgAlert.create().show(); 
    } 

    
    /** 
     * Carga en el ListView la lista de articulos de la base de datos.
     * Si existe un criterio de bsqueda, realiza el filtro correspondientoe. 
     */ 
    @SuppressWarnings("deprecation")
	private void fillData() {
        try{
        	//Obtenemos el cursor teniendo en cuenta el posible filtro de bsqueda
	        Cursor c = mDbHelper.getAllConditionalArticulo(mSearchArticuloText.getText().toString());
	        startManagingCursor(c);
	
	        String[] from = new String[] { ArticuloDBAdapter.CODIARTI, ArticuloDBAdapter.DESCARTI }; 
	        int[] to = new int[] { android.R.id.text1, android.R.id.text2 };
	
	        // Now create an array adapter and set it to display using our row
	        SimpleCursorAdapter articulos = new SimpleCursorAdapter(this, R.layout.two_columns_row, c, from, to);
	        mArticulos.setAdapter(articulos);
        }
        catch (Exception e){
        		msboxFinish("Error en el acceso a los datos.");
        }
    }
    
/*
    @Override
    protected void onListItemClick(ListView l, View v, int position, long id) {
        super.onListItemClick(l, v, position, id);
        TextView label1 = ((TwoLineListItem) v).getText1();
        
    	if (mPermite_navegacion.equalsIgnoreCase("SI")){
	        verPrecios(label1.getText().toString());
    	} else{
    		mCodiartiResult = label1.getText().toString();
    		finish();
    	}
    }
    */
    
    private void verPrecios(String codiarti){
        Intent intent = new Intent(this, ArticuloPrecios.class);
        intent.putExtra(ArticuloDBAdapter.DATABASE_TABLE, codiarti);
        startActivity(intent);
    }
    
    
    /** 
     * Para el retorno de valores cuando esta pantalla se usa para bsqueda de
     * un artculo y retorno, es decir cuando mPermite_navegacion = NO
     */ 
    @Override
    public void finish() {
    	if (mPermite_navegacion.equalsIgnoreCase("NO")){
			// Prepare data intent 
			Intent data = new Intent();
			  
			if (mCodiartiResult.equalsIgnoreCase(""))
				setResult(android.app.Activity.RESULT_CANCELED); // Activity finished canceled, return the data
			else{
				data.putExtra("ARTICULO_KEY", mCodiartiResult);
				setResult(RESULT_OK, data); // Activity finished ok, return the data
			}
    	}
		super.finish();
    } 

    public void onRb1Click (View view){
    	mSearchArticuloText.setInputType(InputType.TYPE_CLASS_NUMBER);
    }
    
    public void onRbAClick (View view){
    	mSearchArticuloText.setInputType(InputType.TYPE_TEXT_FLAG_CAP_CHARACTERS);
    }
    
}
