package com.ventas.pedidoscomercial;

import com.ventas.database.ClienteDBAdapter;
import com.ventas.database.DBAdapter;
import android.os.Bundle;
import android.text.Editable;
import android.text.InputType;
import android.text.TextWatcher;
import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.database.Cursor;
import android.view.ContextMenu;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.WindowManager;
import android.view.ContextMenu.ContextMenuInfo;
import android.widget.AdapterView;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.SimpleCursorAdapter;
import android.widget.TextView;
import android.widget.TwoLineListItem;
import android.widget.AdapterView.AdapterContextMenuInfo;

/**
 * Muestra una lista de todos los clientes cargados en la base de datos del terminal.
 * Permite introducir un filtro de bsqueda en el campo de texto situado en la parte
 * superior de la pantalla, de manera que si el usuario introduce un nmero, buscar
 * el cliente con dicho cdigo; si intruduce una cadena de texto, buscar en funcin
 * del nombre del cliente.
 */
public class ClienteListActivity extends Activity {
	private String    mPermite_navegacion;
	private DBAdapter mDbHelper;
	private EditText  mSearchClienteText;
	private ListView  mClientes;  
	private String    mCodiclieResult = ""; //Resultado en bsquedas
    private static final int RIESGO_ID = Menu.FIRST;
    private static final int DETALLE_ID = Menu.FIRST + 1;
    private static final int PRECIOS_ID = Menu.FIRST + 2;

    
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.two_columns_list);

        // Get the message from the intent
        Intent intent = getIntent();
        mPermite_navegacion = intent.getStringExtra("PERMITE_NAVEGACION");

        mSearchClienteText = (EditText) findViewById(R.id.search); 
        mClientes = (ListView) findViewById(R.id.mlist); 
        registerForContextMenu(mClientes);  //Registers a context menu to be shown for the given view

        try{
	        mDbHelper = new DBAdapter(this);
	        mDbHelper.open();
        }
        catch (Exception e){
        	msboxFinish("Error en el acceso a los datos.");
        	return;
        }
        

        //Rellenar con todos los clientes de la base de datos
        fillData();

        //Eventos sobre el campo de texto para detectar la introduccin de texto
        //y filtrar los clientes.
        mSearchClienteText.addTextChangedListener(new TextWatcher() { 
            public void onTextChanged(CharSequence s, int start, int before, int count){ 
                fillData();
            } 
        
            public void beforeTextChanged(CharSequence s, int start, int count, int after){ 
            } 
        
            public void afterTextChanged(Editable s){
            } 
        }); 

        
        mClientes.setOnItemClickListener(new ListView.OnItemClickListener(){

	    	   public void onItemClick(AdapterView<?> adapter, View view, int position, long id) {
	    		    //protected void onListItemClick(ListView l, View v, int position, long id) {
	    		        //super.onListItemClick(l, view, position, id);
    		        TextView label1 = ((TwoLineListItem) view).getText1();

    		    	if (mPermite_navegacion.equalsIgnoreCase("SI")){
    			        verPrecios(id);
    		    	} else{
    		    		mCodiclieResult = label1.getText().toString();
    		    		finish();
    		    	}
	    	   }

	    });

		getWindow().setSoftInputMode(WindowManager.LayoutParams.SOFT_INPUT_STATE_HIDDEN);
    }

    public void onDestroy() {
    	super.onDestroy();

    	mDbHelper.close();
    }


    public void msboxFinish(String str) 
    { 
        AlertDialog.Builder dlgAlert  = new AlertDialog.Builder(this);                       
        dlgAlert.setMessage(str);  
        dlgAlert.setPositiveButton("Aceptar",new DialogInterface.OnClickListener() { 
            public void onClick(DialogInterface dialog, int whichButton) {
                finish();  
            } 
       }); 

        dlgAlert.setCancelable(true); 
        dlgAlert.create().show(); 
    } 

    
    /** 
     * Carga en el ListView la lista de clientes de la base de datos.
     * Si existe un criterio de bsqueda, realiza el filtro correspondientoe. 
     */ 
    @SuppressWarnings("deprecation")
	private void fillData() {
        try{
        	//Obtenemos el cursor teniendo en cuenta el posible filtro de bsqueda
	        Cursor c = mDbHelper.getAllConditionalCliente(mSearchClienteText.getText().toString());
	        startManagingCursor(c);
	
	        String[] from = new String[] { ClienteDBAdapter.CODICLIE, ClienteDBAdapter.DESCRIPCION }; 
	        int[] to = new int[] { android.R.id.text1, android.R.id.text2 };
	
	        // Now create an array adapter and set it to display using our row
	        SimpleCursorAdapter clientes = new SimpleCursorAdapter(this, R.layout.two_columns_row, c, from, to);
	        mClientes.setAdapter(clientes);
        }
        catch (Exception e){
        		msboxFinish("Error en el acceso a los datos.");
        }
    }
    
    /*
    protected void onListItemClick(ListView l, View v, int position, long id) {
        super.onListItemClick(l, v, position, id);
        TextView label1 = ((TwoLineListItem) v).getText1();

    	if (mPermite_navegacion.equalsIgnoreCase("SI")){
	        verPrecios(id);
    	} else{
    		mCodiclieResult = label1.getText().toString();
    		finish();
    	}

    }
    */
    
    
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
    	if (mPermite_navegacion.equalsIgnoreCase("SI")){
	        super.onCreateOptionsMenu(menu);
	        menu.add(0, RIESGO_ID, 0, R.string.title_activity_cliente_riesgo);
	        menu.add(0, DETALLE_ID, 0, R.string.title_activity_cliente_view);
	        menu.add(0, PRECIOS_ID, 0, R.string.title_activity_articulo_precios);
    	}
    	return true;
    }

    @Override
    public boolean onMenuItemSelected(int featureId, MenuItem item) {
    	AdapterContextMenuInfo info = null;
    	
        switch(item.getItemId()) {
	        case RIESGO_ID:
                info = (AdapterContextMenuInfo) item.getMenuInfo();
                verRiesgo((long)info.id);
	            return true;
	        case DETALLE_ID:
                info = (AdapterContextMenuInfo) item.getMenuInfo();
                verDetalle((long)info.id);
	            return true;
	        case PRECIOS_ID:
                info = (AdapterContextMenuInfo) item.getMenuInfo();
                verPrecios((long)info.id);
	            return true;
        }

        return super.onMenuItemSelected(featureId, item);
    }

    
    @Override
    public void onCreateContextMenu(ContextMenu menu, View v, ContextMenuInfo menuInfo) {
    	if (mPermite_navegacion.equalsIgnoreCase("SI")){
	        super.onCreateContextMenu(menu, v, menuInfo);
	        menu.add(0, RIESGO_ID, 0, R.string.title_activity_cliente_riesgo);
	        menu.add(0, DETALLE_ID, 0, R.string.title_activity_cliente_view);
	        menu.add(0, PRECIOS_ID, 0, R.string.title_activity_articulo_precios);
    	}
    }

    @Override
    public boolean onContextItemSelected(MenuItem item) {
    	AdapterContextMenuInfo info = null;
    	
        switch(item.getItemId()) {
	        case RIESGO_ID:
                info = (AdapterContextMenuInfo) item.getMenuInfo();
                verRiesgo((long)info.id);
	            return true;
	        case DETALLE_ID:
                info = (AdapterContextMenuInfo) item.getMenuInfo();
                verDetalle((long)info.id);
	            return true;
	        case PRECIOS_ID:
                info = (AdapterContextMenuInfo) item.getMenuInfo();
                verPrecios((long)info.id);
	            return true;
        }
        return super.onContextItemSelected(item);
    }

    private void verDetalle(long codiclie){
        Intent intent = new Intent(this, ClienteView.class);
        intent.putExtra(ClienteDBAdapter.CODICLIE, codiclie);
        startActivity(intent);
    }

    private void verRiesgo(long codiclie){
        Intent intent = new Intent(this, ClienteRiesgo.class);
        intent.putExtra(ClienteDBAdapter.CODICLIE, codiclie);
        startActivity(intent);
    }

    private void verPrecios(long codiclie){
        Intent intent = new Intent(this, ArticuloPrecios.class);
        intent.putExtra(ClienteDBAdapter.DATABASE_TABLE, ((Long)codiclie).toString());
        startActivity(intent);
    }
    
    /** 
     * Para el retorno de valores cuando esta pantalla se usa para bsqueda de
     * un artculo y retorno, es decir cuando mPermite_navegacion = NO
     */ 
    @Override
    public void finish() {
    	if (mPermite_navegacion.equalsIgnoreCase("NO")){
			// Prepare data intent 
			Intent data = new Intent();
			  
			if (mCodiclieResult.equalsIgnoreCase(""))
				setResult(android.app.Activity.RESULT_CANCELED); // Activity finished canceled, return the data
			else{
				data.putExtra("CLIENTE_KEY", mCodiclieResult);
				setResult(RESULT_OK, data); // Activity finished ok, return the data
			}
    	}
		super.finish();
    } 

    public void onRb1Click (View view){
    	mSearchClienteText.setInputType(InputType.TYPE_CLASS_NUMBER);
    }
    
    public void onRbAClick (View view){
    	mSearchClienteText.setInputType(InputType.TYPE_TEXT_FLAG_CAP_CHARACTERS);
    }
}
