package com.ventas.pedidoscomercial;

import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.Date;

import com.ventas.database.ClienteDBAdapter;
import com.ventas.database.DBAdapter;
import com.ventas.database.RiesclieDBAdapter;

import android.os.Bundle;
import android.widget.TextView;
import android.app.Activity;
import android.database.Cursor;

public class ClienteRiesgo extends Activity {

	private Long      mCodiclie;
	private DBAdapter mDbHelper; 

	private TextView  mRiesgo_clienteText;
	private TextView  mRiesgo_fechaText;
	private TextView  mFact_pendText;
	private TextView  mCheq_pendText;
	private TextView  mCheq_devuText;
	private TextView  mCheq_cobrText;
	private TextView  mAlba_pendText;
	private TextView  mRies_concText;
	private TextView  mDeud_actuText;
	
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_cliente_riesgo);

        try{
	        mDbHelper = new DBAdapter(this);
	        mDbHelper.open();
        }
        catch (Exception e){
        	return;
        }

        // Get the message from the intent
        mCodiclie = (savedInstanceState == null) ? null :
        	(Long) savedInstanceState.getSerializable(ClienteDBAdapter.CODICLIE);
		if (mCodiclie == null) {
			Bundle extras = getIntent().getExtras();
			mCodiclie = extras != null ? extras.getLong(ClienteDBAdapter.CODICLIE)
									: null;
		}

		mRiesgo_clienteText = (TextView) findViewById(R.id.ries_cliente);
		mRiesgo_fechaText   = (TextView) findViewById(R.id.ries_fecha);
		mFact_pendText      = (TextView) findViewById(R.id.ries_fact_pend);
		mCheq_pendText      = (TextView) findViewById(R.id.ries_cheq_pend);
		mCheq_devuText      = (TextView) findViewById(R.id.ries_cheq_devu);
		mCheq_cobrText      = (TextView) findViewById(R.id.ries_cheq_cobr);
		mAlba_pendText      = (TextView) findViewById(R.id.ries_alba_pend);
		mRies_concText      = (TextView) findViewById(R.id.ries_conc);
		mDeud_actuText      = (TextView) findViewById(R.id.ries_deud_actu);
        
		populateFields();
    }

    public void onDestroy() {
    	super.onDestroy();

    	mDbHelper.close();
    }

    private void populateFields() {

    	try{
        	mRiesgo_clienteText.setText("");
        	mRiesgo_fechaText.setText("");
        	mFact_pendText.setText("");
        	mCheq_pendText.setText("");
        	mCheq_devuText.setText("");
        	mCheq_cobrText.setText("");
        	mAlba_pendText.setText("");
        	mRies_concText.setText("");
        	mDeud_actuText.setText("");

        	if (mCodiclie != null) {
	            Cursor cliente  = mDbHelper.getCliente(mCodiclie.intValue());
	            Cursor riesclie = mDbHelper.getRiesclie(mCodiclie.intValue());
	            
	            if (cliente.getCount() > 0){
	            	mRiesgo_clienteText.setText(cliente.getString(cliente.getColumnIndexOrThrow(ClienteDBAdapter.DESCRIPCION)));
	            }
	            cliente.close();

	            if (riesclie.getCount() > 0){
	            	DecimalFormat nf = new DecimalFormat("###,##0.00");
	            	
	            	String strDate = riesclie.getString(riesclie.getColumnIndexOrThrow(RiesclieDBAdapter.FECHACTU));
	            	Date dtDate = (new SimpleDateFormat("yyyy/MM/dd")).parse(strDate);	
	            	strDate = (new SimpleDateFormat("dd/MM/yyy")).format(dtDate);

	            	mRiesgo_fechaText.setText(strDate);
	            	
	            	mFact_pendText.setText(nf.format(riesclie.getDouble(riesclie.getColumnIndexOrThrow(RiesclieDBAdapter.FACTPEND))));
	            	mCheq_pendText.setText(nf.format(riesclie.getDouble(riesclie.getColumnIndexOrThrow(RiesclieDBAdapter.CHEQPEND))));
	            	mCheq_devuText.setText(nf.format(riesclie.getDouble(riesclie.getColumnIndexOrThrow(RiesclieDBAdapter.CHEQDEVU))));
	            	mCheq_cobrText.setText(nf.format(riesclie.getDouble(riesclie.getColumnIndexOrThrow(RiesclieDBAdapter.CHEQRECO))));
	            	mAlba_pendText.setText(nf.format(riesclie.getDouble(riesclie.getColumnIndexOrThrow(RiesclieDBAdapter.ALBAPEFA))));
	            	mRies_concText.setText(nf.format(riesclie.getDouble(riesclie.getColumnIndexOrThrow(RiesclieDBAdapter.RIESCONC))));

	            	Double deuda = riesclie.getDouble(riesclie.getColumnIndexOrThrow(RiesclieDBAdapter.FACTPEND)) + 
	            			       riesclie.getDouble(riesclie.getColumnIndexOrThrow(RiesclieDBAdapter.CHEQPEND)) + 
         			               riesclie.getDouble(riesclie.getColumnIndexOrThrow(RiesclieDBAdapter.CHEQDEVU)) + 
	            			       riesclie.getDouble(riesclie.getColumnIndexOrThrow(RiesclieDBAdapter.CHEQRECO)) + 
	            			       riesclie.getDouble(riesclie.getColumnIndexOrThrow(RiesclieDBAdapter.ALBAPEFA));
	            	
	            	mDeud_actuText.setText(nf.format(deuda));
	            }
	            riesclie.close();
	        }
    	}
    	catch (Exception e){
    		return;
    	}
    	
    }
}

