package com.ventas.pedidoscomercial;

import com.ventas.database.DBAdapter;
import com.ventas.database.FmenartDBAdapter;
import com.ventas.database.FmencliDBAdapter;
import android.os.Bundle;
import android.text.Editable;
import android.text.InputType;
import android.text.TextWatcher;
import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.database.Cursor;
import android.view.View;
import android.view.WindowManager;
import android.widget.AdapterView;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.SimpleCursorAdapter;
import android.widget.TextView;
import android.widget.TwoLineListItem;

/**
 * Muestra una lista de todos los mensajes cargados en la base de datos del terminal.
 * Permite introducir un filtro de bsqueda en el campo de texto situado en la parte
 * superior de la pantalla, de manera que si el usuario introduce un nmero, buscar
 * el articulo con dicho cdigo; si intruduce una cadena de texto, buscar en funcin
 * del nombre del articulo.
 */
public class MenListActivity extends Activity {
	
	private final int REQUEST_MENCLI = 10;
	private final int REQUEST_MENART = 11;
	
	private int	mTabla;
	private DBAdapter mDbHelper;
	private EditText  mSearchMensajeText;
	private ListView  mMensajes;  
	private String    mCodiResult = ""; //Resultado en bsquedas

    
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.two_columns_list);

        // Get the message from the intent
		if (savedInstanceState != null) {
			mTabla = savedInstanceState.getInt("TABLA");
		}
		else { 
			Bundle extras = getIntent().getExtras();
			if (extras != null) {
				mTabla = extras.getInt("TABLA");
			}
		}
        
        mSearchMensajeText = (EditText) findViewById(R.id.search); 
        mMensajes = (ListView) findViewById(R.id.mlist); 
        registerForContextMenu(mMensajes);  //Registers a context menu to be shown for the given view

        try{
	        mDbHelper = new DBAdapter(this);
	        mDbHelper.open();
        }
        catch (Exception e){
        	msboxFinish("Error en el acceso a los datos.");
        	return;
        }
        

        //Rellenar con todos los mensajes de la base de datos
        fillData();

        //Eventos sobre el campo de texto para detectar la introduccin de texto
        //y filtrar los articulos.
        mSearchMensajeText.addTextChangedListener(new TextWatcher() { 
            public void onTextChanged(CharSequence s, int start, int before, int count){ 
                fillData();
            } 
        
            public void beforeTextChanged(CharSequence s, int start, int count, int after){ 
            } 
        
            public void afterTextChanged(Editable s){
            } 
        }); 

        mMensajes.setOnItemClickListener(new ListView.OnItemClickListener(){

	    	   public void onItemClick(AdapterView<?> adapter, View view, int position, long id) {
	    		    //protected void onListItemClick(ListView l, View v, int position, long id) {
	    		        //super.onListItemClick(l, view, position, id);
	    	        TextView label1 = ((TwoLineListItem) view).getText1();
	    	        mCodiResult = label1.getText().toString();
    	    		finish();
	    	   }
	    });

		getWindow().setSoftInputMode(WindowManager.LayoutParams.SOFT_INPUT_STATE_HIDDEN);
    }

    public void onDestroy() {
    	super.onDestroy();

    	mDbHelper.close();
    }


    public void msboxFinish(String str) 
    { 
        AlertDialog.Builder dlgAlert  = new AlertDialog.Builder(this);                       
        dlgAlert.setMessage(str);  
        dlgAlert.setPositiveButton("Aceptar",new DialogInterface.OnClickListener() { 
            public void onClick(DialogInterface dialog, int whichButton) {
                finish();  
            } 
       }); 

        dlgAlert.setCancelable(true); 
        dlgAlert.create().show(); 
    } 

    
    /** 
     * Carga en el ListView la lista de mensajes de la base de datos.
     * Si existe un criterio de bsqueda, realiza el filtro correspondientoe. 
     */ 
    @SuppressWarnings("deprecation")
	private void fillData() {
        try{
        	//Obtenemos el cursor teniendo en cuenta el posible filtro de bsqueda
	        Cursor curM = null;
	        String[] from = null;
	
	        switch (mTabla) {
	        	case REQUEST_MENCLI:
	        		curM = mDbHelper.getAllConditionalMencli( mSearchMensajeText.getText().toString() );
	    	        startManagingCursor(curM);
	    	
	    	        from = new String[] { FmencliDBAdapter.CODIMCLI, FmencliDBAdapter.DESCMCLI };
	    	        break;
	    	        
	        	case REQUEST_MENART:
	        		//Cursor c = mDbHelper.getAllConditionalArticulo(mSearchMensajeText.getText().toString());
	        		curM = mDbHelper.getAllConditionalMenart( mSearchMensajeText.getText().toString() );
	    	        startManagingCursor(curM);
	    	
	    	        from = new String[] { FmenartDBAdapter.CODIMART, FmenartDBAdapter.DESCMART }; 
	    	        break;
	    	        
	        }
	        
	        int[] to = new int[] { android.R.id.text1, android.R.id.text2 };
	        
	        // Now create an array adapter and set it to display using our row
	        SimpleCursorAdapter mensajes = new SimpleCursorAdapter(this, R.layout.two_columns_row, curM, from, to);
	        mMensajes.setAdapter(mensajes);
        }
        catch (Exception e){
        		msboxFinish("Error en el acceso a los datos.");
        }
    }
    
   
    
    /** 
     * Para el retorno de valores
     */ 
    @Override
    public void finish() {
		// Prepare data intent 
		Intent data = new Intent();
		  
		if (mCodiResult.equalsIgnoreCase(""))
			setResult(android.app.Activity.RESULT_CANCELED); // Activity finished canceled, return the data
		else{
			data.putExtra("MENSAJE", mCodiResult);
			setResult(RESULT_OK, data); // Activity finished ok, return the data
		}
    	
		super.finish();
    } 

    public void onRb1Click (View view){
    	mSearchMensajeText.setInputType(InputType.TYPE_CLASS_NUMBER);
    }
    
    public void onRbAClick (View view){
    	mSearchMensajeText.setInputType(InputType.TYPE_TEXT_FLAG_CAP_CHARACTERS);
    }
    
}
