package com.ventas.pedidoscomercial;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import com.ventas.database.ClienteDBAdapter;
import com.ventas.database.DBAdapter;
import com.ventas.database.FcliDBAdapter;
import com.ventas.database.FpevtcbDBAdapter;

import android.os.Bundle;
import android.app.Activity;
import android.app.AlertDialog;
import android.app.DatePickerDialog;
import android.app.Dialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.database.Cursor;
import android.text.Editable;
import android.text.InputType;
import android.text.TextWatcher;
import android.view.Menu;
import android.view.View;
import android.view.WindowManager;
import android.widget.AdapterView;
import android.widget.DatePicker;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.SimpleCursorAdapter;
import android.widget.TextView;

public class NewPedido extends Activity {
	
	private static final int DATE_DIALOG_ID = 0;
	
	private int mYear;
    private int mMonth;
    private int mDay;
    private Date dtDate;
    
    private TextView mFechaText;
    private EditText  mSearchClienteText;
    private ListView  mClientes;    
    
	private DBAdapter 	mDbHelper; 
    
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_new_pedido);
        
        try{
	        mDbHelper = new DBAdapter(this);
	        mDbHelper.open();
        }
        catch (Exception e){
        	return;
        }
        
        
        mFechaText = (TextView) findViewById(R.id.NewFecha);
        mSearchClienteText = (EditText) findViewById(R.id.search); 
        mClientes = (ListView) findViewById(R.id.mlist); 
        
        registerForContextMenu(mClientes);
        
		//Ocultar el teclado
	    getWindow().setSoftInputMode(WindowManager.LayoutParams.SOFT_INPUT_STATE_HIDDEN);
        
	    //calcular fecha
	    Calendar c = Calendar.getInstance();
	    if (c.get(Calendar.DAY_OF_WEEK) == Calendar.SATURDAY) {
		    c.add(Calendar.DAY_OF_YEAR, 2);
	    }
	    else {
		    c.add(Calendar.DAY_OF_YEAR, 1);
	    }
	    dtDate = c.getTime();
	    
	    DisplayDate();
	    
      //Al pulsar en fecha mostrar el DatePicker
        mFechaText.setOnClickListener(new View.OnClickListener() {
			
			@SuppressWarnings("deprecation")
			public void onClick(View v) {
				showDialog(DATE_DIALOG_ID);
			}

		});
	    
        
        //Eventos sobre el campo de texto para detectar la introduccin de texto
        //y filtrar los clientes.
        mSearchClienteText.addTextChangedListener(new TextWatcher() { 
            public void onTextChanged(CharSequence s, int start, int before, int count){ 
                fillData();
            } 
        
            public void beforeTextChanged(CharSequence s, int start, int count, int after){ 
            } 
        
            public void afterTextChanged(Editable s){
            } 
        }); 
	    
        mClientes.setOnItemClickListener(new ListView.OnItemClickListener(){

	    	   public void onItemClick(AdapterView<?> adapter, View view, int position, long id) {
	    		   System.out.println("Crear pedido al " + id);
	    		   newPedido(id, dtDate);
	    	   }

	    });
        
        //Rellenar con todos los clientes de la base de datos
        fillData();
    }

    public void onDestroy() {
    	super.onDestroy();

    	mDbHelper.close();
    }
    
	@Override
	protected Dialog onCreateDialog(int id, Bundle args) {
		switch (id) {
		case DATE_DIALOG_ID:
			Calendar c = Calendar.getInstance();
			c.setTime(dtDate);
			mYear = c.get(Calendar.YEAR);
            mMonth = c.get(Calendar.MONTH);
            mDay = c.get(Calendar.DAY_OF_MONTH);
			
			return new DatePickerDialog(this, mDateSetListener, mYear, mMonth, mDay);
				
		}
		return null;
	}
	
	// the callback received when the user "sets" the date in the dialog
    private DatePickerDialog.OnDateSetListener mDateSetListener = new DatePickerDialog.OnDateSetListener() {

        public void onDateSet(DatePicker view, int year, int monthOfYear, int dayOfMonth) {
            mYear = year;
            mMonth = monthOfYear;
            mDay = dayOfMonth;
            
            Calendar ayer = Calendar.getInstance();
            Calendar cal = Calendar.getInstance();
            
            cal.set( year, monthOfYear, dayOfMonth);
            ayer.add(Calendar.DAY_OF_YEAR, -1);
            
            if (cal.getTime().after( ayer.getTime())) {
            	dtDate = cal.getTime();
                DisplayDate();
            }
            else {
            	msgBox("Debe cambiar la fecha de servir", "Error", false);
            }
            
        }
        
	};

	//Formatea la fecha y la asigna al TextView
	private void DisplayDate() {
		DateFormat df = DateFormat.getDateInstance(DateFormat.FULL);
		mFechaText.setText(df.format(dtDate).toUpperCase());
	}
    
    public void msgBox(String str, String titulo, boolean fin) { 
        AlertDialog.Builder dlgAlert  = new AlertDialog.Builder(this);                       
        dlgAlert.setMessage(str);  
        dlgAlert.setTitle(titulo);
        if (fin) {
	        dlgAlert.setPositiveButton("Aceptar",new DialogInterface.OnClickListener() { 
	            public void onClick(DialogInterface dialog, int whichButton) {
	                finish();  
	            } 
	        }); 
        }
        else {
            dlgAlert.setPositiveButton("Aceptar",null); 
        }
        dlgAlert.setCancelable(true); 
        dlgAlert.create().show(); 
    } 

    
    /** 
     * Carga en el ListView la lista de clientes de la base de datos.
     * Si existe un criterio de bsqueda, realiza el filtro correspondientoe. 
     */ 
    @SuppressWarnings("deprecation")
	private void fillData() {
        try{
        	//Obtenemos el cursor teniendo en cuenta el posible filtro de bsqueda
	        Cursor c = mDbHelper.getAllConditionalCliente(mSearchClienteText.getText().toString());
	        startManagingCursor(c);
	
	        String[] from = new String[] { ClienteDBAdapter.CODICLIE, ClienteDBAdapter.DESCRIPCION }; 
	        int[] to = new int[] { android.R.id.text1, android.R.id.text2 };
	
	        // Now create an array adapter and set it to display using our row
	        SimpleCursorAdapter clientes = new SimpleCursorAdapter(this, R.layout.two_columns_row, c, from, to);
	        mClientes.setAdapter(clientes);
        }
        catch (Exception e){
        		msgBox("Error en el acceso a los datos.", "", true);
        }
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        //getMenuInflater().inflate(R.menu.activity_new_pedido, menu);
        return true;
    }
    
	private void newPedido(long codiclie, Date fecha){
	    Intent intent = new Intent(this, Pedidos.class);
	    
	    String strDate = (new SimpleDateFormat("yyyy/MM/dd")).format(dtDate);
	    
	    String codimcli = "";
	    Cursor curMen = mDbHelper.getFcli(codiclie);
	    if (curMen.getCount() > 0 ) {
	    	codimcli = curMen.getString(curMen.getColumnIndexOrThrow(FcliDBAdapter.CODIMCLI));
	    	curMen.close();
	    }
	    
	    if (mDbHelper.getPevtcb(codiclie, strDate).getCount() == 0) {
	    	String strDateLong = (new SimpleDateFormat("yyyy/MM/dd HH:mm:ss")).format(dtDate);
		    mDbHelper.createPevtcb(strDateLong, codiclie, codimcli, "");
	    }
	    
	    intent.putExtra(FpevtcbDBAdapter.CODICLIE, codiclie);
	    intent.putExtra(FpevtcbDBAdapter.FECHA, strDate);
	    
	    startActivity(intent);
	}
	
    public void onRb1Click (View view){
    	mSearchClienteText.setInputType(InputType.TYPE_CLASS_NUMBER);
    }
    
    public void onRbAClick (View view){
    	mSearchClienteText.setInputType(InputType.TYPE_TEXT_FLAG_CAP_CHARACTERS);
    }
    
}
