package com.ventas.pedidoscomercial;

import java.io.BufferedReader;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.Socket;

import com.ventas.database.ConfigDBAdapter;
import com.ventas.database.DBAdapter;
import com.ventas.database.FmenartDBAdapter;
import com.ventas.database.FmencliDBAdapter;
import com.ventas.database.FpevtcbDBAdapter;
import com.ventas.database.FpevtlnDBAdapter;

import android.os.Bundle;
import android.app.Activity;
import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.content.Intent;
import android.content.res.AssetManager;
import android.database.Cursor;
import android.graphics.Color;
import android.telephony.TelephonyManager;
import android.text.InputFilter;
import android.text.InputType;
import android.text.Spanned;
import android.util.Log;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;
import android.graphics.PorterDuff;


public class SyncActivity extends Activity {
	
	private DBAdapter 	mDbHelper;
	
	private String operacion_sync;
	private String ip_destino;			//Nombre del servidor
	private int    puerto;   			//Puerto base para conectarnos
	private int    id_terminal;		    //Identificacin del terminal
	private String nom_terminal;		//Nombre del terminal
	private String uid;				    //Unique Id del dispositivo
	private final String    VERSION_APK = "V.ANDROID.02";
	private final String 	PROTOCOLO_IMPORTACION_COMPLETA = "14";
	private final String 	PROTOCOLO_IMPORTACION_PARCIAL  = "15";
	private final String 	PROTOCOLO_ENVIO_PEDIDOS        = "16";
	private final String    FICHERO_PEDIDOS                = "pedidos.piz";
	private final String    FICHERO_DATOS_GENERALES        = "General.xml";
	private final String    FICHERO_IMPORTACION_COMPLETA   = "trascomp.txt";
	private final String    FICHERO_IMPORTACION_PARCIAL    = "trasparc.txt";

	private Socket           socketClient         = null;
	private DataOutputStream dataOutputStream     = null;
	private DataInputStream  dataInputStream      = null;

	private Socket           socketClientFile     = null;
	private DataOutputStream dataOutputStreamFile = null;
	private DataInputStream  dataInputStreamFile  = null;
	
	private boolean          actualizandoVentas   = false;  //Mientras se est actualizando la base de datos, no permitir destruir la actividad
	private int              numBack              = 0;      //Nmero de veces que se ha pulsado la tacla Back durante la actualizacin de la BD

	private TextView textView;
	private Button   btSync;
	
    @Override
    public void onCreate(Bundle savedInstanceState) {
    	
        super.onCreate(savedInstanceState);

        try{
	        mDbHelper = new DBAdapter(this);
	        mDbHelper.open();
        }
        catch (Exception e){
        	return;
        }
        
        // Get the message from the intent
        Intent intent = getIntent();
        operacion_sync = intent.getStringExtra(MainActivity.OPERACION_SYNC);

        setContentView(R.layout.activity_sync);

        datosConfig();
        
        btSync = (Button) findViewById(R.id.button_sincronizar);

        // Fill the text view
        textView = (TextView) findViewById(R.id.text_sync);
        textView.setSingleLine(false);
        textView.setTextSize(20);
        
        if (operacion_sync.compareTo(MainActivity.ENVIO_DE_PEDIDOS) == 0){
        	btSync.getBackground().setColorFilter(MainActivity.COLOR_BASE, PorterDuff.Mode.MULTIPLY);        	
        	textView.setTextColor(MainActivity.COLOR_BASE);
        	textView.setText("ATENCIN: Va a realizar el ENVO DE LOS PEDIDOS al" +
					" servidor e IMPORTACIN PARCIAL de la base de datos.");
        }

        if (operacion_sync.compareTo(MainActivity.IMPORTACION_COMPLETA) == 0){
        	btSync.getBackground().setColorFilter(MainActivity.COLOR_AZUL, PorterDuff.Mode.MULTIPLY);
        	textView.setTextColor(MainActivity.COLOR_AZUL);
        	textView.setText("ATENCIN: Va a realizar una IMPORTACIN COMPLETA de" +
					" la Base de datos del servidor.Esto sincronizar el terminal" +
        			" con el servidor");
        }

        if (operacion_sync.compareTo(MainActivity.IMPORTACION_PARCIAL) == 0){
        	btSync.getBackground().setColorFilter(MainActivity.COLOR_AZUL, PorterDuff.Mode.MULTIPLY);
        	textView.setTextColor(MainActivity.COLOR_AZUL);
        	textView.setText("ATENCIN: Va a realizar una IMPORTACIN PARCIAL de la" +
					" Base de datos del servidor. Esto sincronizar el" +
					" terminal con las ltimas modificaciones realizadas" +
					" en el servidor.");
        }

        //ESTA PARTE ES SOLO PARA LA IMPORTACION LOCAL A MODO DEMO
        //PENDIENTE DE BORRAR
        if (operacion_sync.compareTo("IMPORTACION COMPLETA LOCAL") == 0){
        	btSync.getBackground().setColorFilter(MainActivity.COLOR_VERDE, PorterDuff.Mode.MULTIPLY);
        	textView.setTextColor(MainActivity.COLOR_VERDE);
        	textView.setText("ATENCIN: Va a realizar una IMPORTACIN COMPLETA LOCAL. "+
        					"Esto importara archivos locales en el dispositivo.");
        }      
    }

    public void onDestroy() {
    	mDbHelper.close();
    	cerrarPuertos();
    	
    	super.onDestroy();
    }

    /** 
     * Controla que se ha pulsado el botn Atrs durante la transmisin.
     * Debemos tener en cuenta que la acctualizacin de la base de datos
     * no se debe cancelar. 
     *  
     * @return void 
     */ 
    public void onBackPressed() { 
    	if ((actualizandoVentas) && (numBack < 5)){ 
    		numBack++;
    		moveTaskToBack(true); 
    	}
    	else 
    		super.onBackPressed();
    } 

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        //getMenuInflater().inflate(R.menu.activity_sync, menu);
        return true;
    }
    
    /** Called when the user clicks the sincronizar button */
    public void sincronizar(View view) {
    	textView.setTextSize(14);
    	textView.setTextColor(MainActivity.COLOR_AZUL);
        btSync.setVisibility(View.INVISIBLE);

    	new Thread(new Runnable() {
            public void run() {

		        if (operacion_sync.compareTo(MainActivity.ENVIO_DE_PEDIDOS) == 0){
		        	envioPedidos();
		        }
		
		        if (operacion_sync.compareTo(MainActivity.IMPORTACION_COMPLETA) == 0){
		        	importacionCompleta();
		        }
		
		        if (operacion_sync.compareTo(MainActivity.IMPORTACION_PARCIAL) == 0){
		        	importacionParcial();
		        }
		        
		        //ESTA PARTE ES SOLO PARA LA IMPORTACION LOCAL A MODO DEMO
		        //PENDIENTE DE BORRAR
		        if (operacion_sync.compareTo("IMPORTACION COMPLETA LOCAL") == 0){
		        	importacionCompletaLocal();
		        }

            }
           
        }).start();
    }

    private void envioPedidos() {
    	String respuesta = null;
    	
        try {
	    	//PASO UNO:     Iniciar el protocolo de comunicacin
          	setText("Iniciando el protocolo de comunicacin.\r\n\r\n");
	    	iniciaProtocoloComunicacion();

	    	//PASO DOS:     El protocolo de comunicacin es "ENVO DE PEDIDOS"
			//De acuerdo con el protocolo definido por el servidor, el valor 14 indica al servidor la intencin
			//de solicitar una importacin completa.
			addText("El protocolo es ENVO DE PEDIDOS.\r\n\r\n");
			dataOutputStream.writeBytes(PROTOCOLO_ENVIO_PEDIDOS);
			
			//PASO TRES: 	Esperar la confirmacin del servidor.
			addText("Esperando confirmacin del servidor.\r\n\r\n");
			respuesta = esperarConfimacion();

			//PASO CUATRO: 	Iniciar el protocolo de comunicacin de transferencia de ficheros
			addText("Iniciando la transferencia de ficheros.\r\n\r\n");
			iniciaProtocoloComunicacionFile();

            //PASO CINCO:    Se le manda el nombre de terminal y empresa
            enviarIdentificacion(dataOutputStream);
            respuesta = esperarConfimacion(); 
            if (respuesta.compareTo("6") != 0)  // Recepcion OK.
            {
    	    	setTextColor(MainActivity.COLOR_ROJO);
    	    	addText("Error: " + respuesta);
    	        cerrarPuertos();
    			return;
            }

            //PASO SEIS:  Pasar el pedido a formato Texto pero con extensin .piz.
            int numPeds = generaFicheroPedidos();
            if (numPeds ==0){
    	    	setTextColor(MainActivity.COLOR_ROJO);
    	    	addText("Error: No existen pedidos para transmitir.");
    	        cerrarPuertos();
    			return;
            }
            
            //PASO SIETE:  Enviar el fichero texto con los pedidos y esperar confirmacin.
            enviarPedidos();
            addText("Esperando confirmacin del servidor.\r\n\r\n");
			respuesta = esperarConfimacion();
            if (respuesta.compareTo("6") != 0)  // "Recepcion OK."
            {
    	    	setTextColor(MainActivity.COLOR_ROJO);
    	    	addText("Error: " + respuesta);
    	        cerrarPuertos();
    			return;
            }
            
            //PASO OCHO: 	Traerse el fichero General.xml
            addText("Importando parmetros generales.\r\n\r\n");
            dameFichero(FICHERO_DATOS_GENERALES);

            //PASO NUEVE: 	Traerse el fichero trascomp.txt
            addText("Importando Base de Datos.\r\n\r\n");
            dameFichero(FICHERO_IMPORTACION_PARCIAL);

			//PASO DIEZ: 	Esperar la confirmacin del servidor.
            addText("Esperando confirmacin del servidor.\r\n\r\n");
			respuesta = esperarConfimacion();
			
			//PASO ONCE: 	Cerramos los puertos.
	        cerrarPuertos();
	        
	        //PASO DOCE:	Comprobamos si exiten errores en la ltima confirmacin
            if (respuesta.compareTo("6") != 0)  // "Recepcion OK."
            {
    	    	setTextColor(MainActivity.COLOR_ROJO);
    	    	addText("Error: " + respuesta);
    			return;
            }
			
            //PASO TRECE:	Si no hay error, borrar el fichero de texto de pedidos y limpiar las tablas de pedidos.
        	this.borraFicheroPedidos();
        	//DBAdapter dbHelper = new DBAdapter(this);
        	//dbHelper.open();
        	//dbHelper.limpiaPedidos();
        	//dbHelper.close();
        	mDbHelper.limpiaPedidos();
            
            //PASO CATORCE: Actualizamos la base de datos de ventas.
            if (!actualizaVentas(FICHERO_IMPORTACION_PARCIAL, false)){
    	    	setTextColor(MainActivity.COLOR_ROJO);
    	    	addText("Error al actualizar la base de datos local");
    			return;
            }
        } catch (Exception e) {
	    	setTextColor(MainActivity.COLOR_ROJO);
	    	addText("Error en la transmisin de datos.");
	        cerrarPuertos();
			return;
		}  

    	setTextColor(MainActivity.COLOR_AZUL);
    	setTextSize(20);
      	setText("ENVO DE PEDIDOS FINALIZADO");
    }

    
    private void importacionCompleta() {
    	String respuesta = null;
    	
        try {
	    	//PASO UNO:     Iniciar el protocolo de comunicacin
          	setText("Iniciando el protocolo de comunicacin.\r\n\r\n");
	    	iniciaProtocoloComunicacion();

	    	//PASO DOS:     El protocolo de comunicacin es "PETICION BD COMPLETA"
			//De acuerdo con el protocolo definido por el servidor, el valor 14 indica al servidor la intencin
			//de solicitar una importacin completa.
			addText("El protocolo es PETICION BD COMPLETA.\r\n\r\n");
			dataOutputStream.writeBytes(PROTOCOLO_IMPORTACION_COMPLETA);
			
			//PASO TRES: 	Esperar la confirmacin del servidor.
			addText("Esperando confirmacin del servidor.\r\n\r\n");
			respuesta = esperarConfimacion();

			//PASO CUATRO: 	Iniciar el protocolo de comunicacin de transferencia de ficheros
			addText("Iniciando la transferencia de ficheros.\r\n\r\n");
			iniciaProtocoloComunicacionFile();

            //PASO CINCO:    Se le manda el nombre de terminal y empresa
            enviarIdentificacion(dataOutputStream);
            respuesta = esperarConfimacion(); 
            if (respuesta.compareTo("6") != 0)  // Recepcion OK.
            {
    	    	setTextColor(MainActivity.COLOR_ROJO);
    	    	addText("Error: " + respuesta);
    	        cerrarPuertos();
    			return;
            }

            //PASO SEIS: 	Traerse el fichero General.xml
            addText("Importando parmetros generales.\r\n\r\n");
            dameFichero(FICHERO_DATOS_GENERALES);

            //PASO SIETE: 	Traerse el fichero trascomp.txt
            addText("Importando Base de Datos.\r\n\r\n");
            dameFichero(FICHERO_IMPORTACION_COMPLETA);

			//PASO OCHO: 	Esperar la confirmacin del servidor.
            addText("Esperando confirmacin del servidor.\r\n\r\n");
			respuesta = esperarConfimacion();
			
			//PASO NUEVE: 	Cerramos los puertos.
	        cerrarPuertos();
	        
	        //PASO DIEZ:	Comprobamos si exiten errores en la ltima confirmacin
            if (respuesta.compareTo("6") != 0)  // "Recepcion OK."
            {
    	    	setTextColor(MainActivity.COLOR_ROJO);
    	    	addText("Error: " + respuesta);
    			return;
            }
			
            //PASO ONCE: Actualizamos la base de datos de ventas.
            if (!actualizaVentas(FICHERO_IMPORTACION_COMPLETA, true)){
    	    	setTextColor(MainActivity.COLOR_ROJO);
    	    	addText("Error al actualizar la base de datos local");
    			return;
            }
            
        } catch (Exception e) {
	    	setTextColor(MainActivity.COLOR_ROJO);
	    	addText("Error en la transmisin de datos.");
	        cerrarPuertos();
			return;
		}  

        
    	setTextColor(MainActivity.COLOR_AZUL);
    	setTextSize(20);
      	setText("IMPORTACIN COMPLETA FINALIZADA");
    }

    private void importacionParcial() {
    	String respuesta = null;
    	
        try {
	    	//PASO UNO:     Iniciar el protocolo de comunicacin
          	setText("Iniciando el protocolo de comunicacin.\r\n\r\n");
	    	iniciaProtocoloComunicacion();

	    	//PASO DOS:     El protocolo de comunicacin es "PETICION BD COMPLETA"
			//De acuerdo con el protocolo definido por el servidor, el valor 15 indica al servidor la intencin
			//de solicitar una importacin parcial.
	    	addText("El protocolo es PETICION BD PARCIAL.\r\n\r\n");
			dataOutputStream.writeBytes(PROTOCOLO_IMPORTACION_PARCIAL);
			
			//PASO TRES: 	Esperar la confirmacin del servidor.
			addText("Esperando confirmacin del servidor.\r\n\r\n");
			respuesta = esperarConfimacion();

			//PASO CUATRO: 	Iniciar el protocolo de comunicacin de transferencia de ficheros
			addText("Iniciando la transferencia de ficheros.\r\n\r\n");
			iniciaProtocoloComunicacionFile();

            //PASO CINCO:    Se le manda el nombre de terminal y empresa
            enviarIdentificacion(dataOutputStream);
            respuesta = esperarConfimacion(); 
            if (respuesta.compareTo("6") != 0)  // Recepcion OK.
            {
    	    	setTextColor(MainActivity.COLOR_ROJO);
    	    	addText("Error: " + respuesta);
    	        cerrarPuertos();
    			return;
            }

            //PASO SEIS: 	Traerse el fichero General.xml
            addText("Importando parmetros generales.\r\n\r\n");
            dameFichero(FICHERO_DATOS_GENERALES);

            //PASO SIETE: 	Traerse el fichero trasparc.txt
            addText("Importando Base de Datos.\r\n\r\n");
            dameFichero(FICHERO_IMPORTACION_PARCIAL);

			//PASO OCHO: 	Esperar la confirmacin del servidor.
            addText("Esperando confirmacin del servidor.\r\n\r\n");
			respuesta = esperarConfimacion();
			
			//PASO NUEVE: 	Cerramos los puertos.
	        cerrarPuertos();
	        
	        //PASO DIEZ:	Comprobamos si exiten errores en la ltima confirmacin
            if (respuesta.compareTo("6") != 0)  // "Recepcion OK."
            {
    	    	setTextColor(MainActivity.COLOR_ROJO);
    	    	addText("Error: " + respuesta);
    			return;
            }
			
            //PASO ONCE: Actualizamos la base de datos de ventas. En este caso no limpiamos previamente la base de datos
            if (!actualizaVentas(FICHERO_IMPORTACION_PARCIAL, false)){
    	    	setTextColor(MainActivity.COLOR_ROJO);
    	    	addText("Error al actualizar la base de datos local");
    			return;
            }
		} catch (Exception e) {
	    	setTextColor(MainActivity.COLOR_ROJO);
	    	addText("Error en la transmisin de datos.");
	        cerrarPuertos();
			return;
		}  
		
    	setTextColor(MainActivity.COLOR_AZUL);
    	setTextSize(20);
      	setText("IMPORTACIN PARCIAL FINALIZADA");
    }

    private void cerrarPuertos(){
    	
		try{
			if (dataOutputStream != null)
				dataOutputStream.close();
			if (dataInputStream != null)
				dataInputStream.close();
			if (socketClient != null)
				socketClient.close();

			if (dataOutputStreamFile != null)
				dataOutputStreamFile.close();
			if (dataInputStreamFile != null)
				dataInputStreamFile.close();
			if (socketClientFile != null)
				socketClientFile.close();
		} catch (IOException e) {  
		}
    }
    
    //Iniciar el protocolo de comunicacin
    private void iniciaProtocoloComunicacion() throws Exception {
		try {//creamos sockets con los valores anteriores
			socketClient = new Socket(ip_destino, puerto + id_terminal); //El nmero de puerto ms el identificador de terminal
			
			//si no nos conectamos mostramos el error y no seguimos.
			if (socketClient.isConnected() == false) {
				addText("No se ha podido establecer la comunicacin con el servidor.\r\n\r\n");
		      	throw new Exception();
			}
		} catch (Exception e) {
			//Si hubo algun error no nos conectamos mostramos el error y no seguimos.
			addText("Error al establecer la comunicacin con el servidor.\r\n\r\n" + e.getMessage());
			throw (e);
		}
		
		try {
			dataOutputStream = new DataOutputStream(socketClient.getOutputStream());  
			dataInputStream = new DataInputStream(socketClient.getInputStream());  
		} catch (IOException e) {  
			addText("Error al obtener los canales de datos.\r\n\r\n");
	      	throw (e);
		}
    }

    //Iniciar el protocolo de transferencia de ficheros.
    private void iniciaProtocoloComunicacionFile() throws Exception {
		try {//creamos sockets con los valores anteriores
			socketClientFile = new Socket(ip_destino, puerto + id_terminal + 1000); //El nmero de puerto ms el identificador de terminal
			
			//si no nos conectamos mostramos el error y no seguimos.
			if (socketClientFile.isConnected() == false) {
				addText("Imposible iniciar la transferencia de ficheros.\r\n\r\n");
		      	throw new Exception();
			}
		} catch (Exception e) {
			//Si hubo algun error no nos conectamos mostramos el error y no seguimos.
			addText("Error al iniciar la transferencia de ficheros.\r\n\r\n" + e.getMessage());
			throw (e);
		}
		
		try {
			dataOutputStreamFile = new DataOutputStream(socketClientFile.getOutputStream());  
			dataInputStreamFile = new DataInputStream(socketClientFile.getInputStream());  
		} catch (IOException e) {  
			addText("Error al obtener los canales de datos.\r\n\r\n");
	      	throw (e);
		}
    }

    private String esperarConfimacion() throws Exception
	{
		try
		{
			byte[] inputBuffer = new byte[128];
			int bytes = dataInputStream.read(inputBuffer, 0, inputBuffer.length);
			if (bytes < 0)
				return "";

			return new String(inputBuffer, "ASCII").substring(0, bytes);
		}
		catch(Exception e)
		{
			addText("Error en la espera.\r\n\r\n");
	      	throw (e);
		}
	}

    private void enviarConfirmacion() throws Exception
    {
        try
        {
            //El servidor responde que la recepcin es OK.
        	String confirmacion = "6"; //"Recepcin OK";
        	byte[] envio = confirmacion.getBytes();
        	dataOutputStream.write(envio, 0,envio.length);
        }
        catch (Exception e)
        {
        	addText("Error al confirmar.\r\n\r\n");
            throw e;
        }
    }

	private void enviarIdentificacion(DataOutputStream pDataOutputStream) throws Exception
	{
		
		try
		{
			//El formato del mensaje es el siguiente:
				//5 caracteres que identifican al terminal (TC001)
				//2 caracteres como mximo que identifican la empresa
	        TelephonyManager telephonyManager = (TelephonyManager) getSystemService(Context.TELEPHONY_SERVICE);
	        String imei = telephonyManager.getDeviceId();

			String identificacion = this.nom_terminal + "1" + imei +"|" + VERSION_APK; 
	        //String identificacion = this.nom_terminal + this.mDbHelper.getIdEmpActual() + imei +"|" + VERSION_APK;
			identificacion = identificacion.toUpperCase();
			addText("Se enva el mensaje: " + identificacion + "\r\n\r\n");
			byte[] envio = identificacion.getBytes();
			pDataOutputStream.write(envio, 0,envio.length);
		}
		catch(Exception e)
		{
			addText("Error en la identificacin del terminal.\r\n\r\n");
			throw e;
		}
	}

    /** 
     * Realiza la lectura de las tablas de pedidos y genera un fichero de texto llamado
     * pedidos.piz, que ser el que se transmita a la central
     *  
     * @return NumPeds: Nmero de pedidos a transmitir 
     */ 
    private int generaFicheroPedidos() throws Exception
    {
        int       bufsize     = 2500;
        byte[]    inputBuffer = new byte[bufsize];
    	//DBAdapter dbHelper    = new DBAdapter(this);
        Cursor    curMen = null;
        String    lCodimenPred ="";
        String    lCodimen = "";
        String    lTextmen = "";
        
    	//Intentamos borrar el fichero para que, en casos de error en la anterior transmisin,
    	//no se solapen los nuevos pedidos con los antiguos.
    	this.borraFicheroPedidos();

        try
        {
        	//dbHelper.open();
		    //Cursor curFpevtcb   = dbHelper.getAllPevtcb();
		    //Cursor curFpevtln   = dbHelper.getAllPevtln();
        	Cursor curFpevtcb   = mDbHelper.getAllPevtcb();
		    Cursor curFpevtln   = mDbHelper.getAllPevtln();

		    
		    //Si no hay pedidos, no hay fichero que generar.
		    if ((curFpevtcb.getCount() == 0) || (curFpevtln.getCount() == 0))
		    	return 0;
		    
		    int numPeds = curFpevtcb.getCount();
		    
        	FileOutputStream outputStream = openFileOutput(FICHERO_PEDIDOS, Context.MODE_PRIVATE);
            
    		curMen = mDbHelper.getAllFmencli();
    	    if (curMen.getCount() > 0 ) {
    	    	lCodimenPred = curMen.getString(curMen.getColumnIndexOrThrow(FmencliDBAdapter.CODIMCLI));
    	    	curMen.close();
    	    }
    	    
            do
            {
            	lCodimen = curFpevtcb.getString(curFpevtcb.getColumnIndexOrThrow(FpevtcbDBAdapter.CODIMCLI));
            	if (lCodimen.equals("")) {
            		lCodimen = lCodimenPred;
            	}
            	
            	String linea = "If_pevtcb|" + 
            			curFpevtcb.getString(curFpevtcb.getColumnIndexOrThrow(FpevtcbDBAdapter.FECHA)) + "|" +
            			curFpevtcb.getString(curFpevtcb.getColumnIndexOrThrow(FpevtcbDBAdapter.CODIPECB)) + "|" +
            			curFpevtcb.getString(curFpevtcb.getColumnIndexOrThrow(FpevtcbDBAdapter.CODICLIE)) +  "|" +
            			lCodimen + "|" +
            			(curFpevtcb.getString(curFpevtcb.getColumnIndexOrThrow(FpevtcbDBAdapter.TEXTMCLI))).replace("|", " ") + 
            			"\r\n";
            	
                inputBuffer = linea.getBytes();
                outputStream.write(inputBuffer, 0, inputBuffer.length);
            	
            } while (curFpevtcb.moveToNext());

    		curMen = mDbHelper.getAllFmenart();
    	    if (curMen.getCount() > 0 ) {
    	    	lCodimenPred = curMen.getString(curMen.getColumnIndexOrThrow(FmenartDBAdapter.CODIMART));
    	    	curMen.close();
    	    }
            lCodimen = "";
            
            do
            {
            	lCodimen = curFpevtln.getString(curFpevtln.getColumnIndexOrThrow(FpevtlnDBAdapter.CODIMART));
            	lTextmen = curFpevtln.getString(curFpevtln.getColumnIndexOrThrow(FpevtlnDBAdapter.TEXTMART));
            	if ( lCodimen.equals("") &&
            		!lTextmen.equals("") ) {
            		
            		lCodimen = lCodimenPred;
            		
            	}
            	
            	String linea = "If_pevtln|" + 
            			curFpevtln.getString(curFpevtln.getColumnIndexOrThrow(FpevtlnDBAdapter.CODIPELN)) + "|" +
            			curFpevtln.getString(curFpevtln.getColumnIndexOrThrow(FpevtlnDBAdapter.CODIPECB)) + "|" +
            			curFpevtln.getString(curFpevtln.getColumnIndexOrThrow(FpevtlnDBAdapter.CODIARTI)) +  "|" +
            			lCodimen + "|" +
            			"0|" +
            			(curFpevtln.getString(curFpevtln.getColumnIndexOrThrow(FpevtlnDBAdapter.CANTIDAD))).replace(".", ",") + "|" +
            			(curFpevtln.getString(curFpevtln.getColumnIndexOrThrow(FpevtlnDBAdapter.PRECIO))).replace(".", ",") + "|" +
            			(lTextmen).replace("|", " ") + "|" +
            			curFpevtln.getString(curFpevtln.getColumnIndexOrThrow(FpevtlnDBAdapter.CODIUNID)) + "|" +
            			curFpevtln.getString(curFpevtln.getColumnIndexOrThrow(FpevtlnDBAdapter.TIPOPRECIO)) + "|" +
            			curFpevtln.getString(curFpevtln.getColumnIndexOrThrow(FpevtlnDBAdapter.CODIGOBARRAS)) + 
            			"\r\n";

                inputBuffer = linea.getBytes();
                outputStream.write(inputBuffer, 0, inputBuffer.length);

            } while (curFpevtln.moveToNext());

            outputStream.close();
            curFpevtcb.close();
            curFpevtln.close();
            return numPeds;
        }
        catch (Exception e)
        {
        	addText("Error en la preparacin del fichero de pedidos. \r\n\r\n");
            throw e;
        }
    }
	
    /** 
     * Intentamos borrar el fichero para que, en casos de error en la anterior transmisin,
     * no se solapen los nuevos pedidos con los antiguos.
     *  
     */ 
    private void borraFicheroPedidos() throws Exception
    {
        try
        {
        	File dir = getFilesDir(); 
        	File file = new File(dir, FICHERO_PEDIDOS); 
        	file.delete(); 
        }
        catch (Exception e){
        }

    }
	
    private void enviarPedidos() throws Exception
    {
        int Bufsize = 2500;
        byte[] buf  = new byte[Bufsize];          // we will use 2,5kB buffer
        
        try
        {
    		InputStream  SourceFile  = openFileInput(FICHERO_PEDIDOS);

    	    int length;
    	    //copy the file content in bytes 
    	    while ((length = SourceFile.read(buf)) > 0){
    	    	dataOutputStreamFile.write(buf, 0, length);
    	    }

    	    String lstResponse = "" + (char)4;		//Marca de finalizacin de fichero.
            buf    = new byte[1];
            buf[0] = lstResponse.getBytes()[0];
	    	dataOutputStreamFile.write(buf, 0, buf.length);
	    	lstResponse = esperarConfimacion();

    	    SourceFile.close();
        }
        catch (Exception e){
            throw e;
        }
    }

    
    
    /** 
     * Copiar el fichero del servidor en el PATH de sistema del dispositivo
     *  
     * @param fichero  		Fichero de texto destino
     */ 
    private void dameFichero(String fichero) throws Exception
    {
        int              bufsize = 2500;
        byte[]           inputBuffer = new byte[bufsize];

        try
        {
        	FileOutputStream outputStream = openFileOutput("archivo.txt", Context.MODE_PRIVATE);
            int              bytesRead    = 0;
            boolean          endOfFile    = false;

            do
            {
                do
                {
                	bytesRead    = dataInputStreamFile.read(inputBuffer, 0, inputBuffer.length);
                	String leido = new String(inputBuffer, "ASCII").substring(0, bytesRead);
                	int    index = leido.indexOf((char)4);

                	if (index >= 0)
                    {
                    	leido = leido.substring(0, index);
                        if (leido.length() > 0)
                        {
                            inputBuffer = leido.getBytes();
                            outputStream.write(inputBuffer, 0, inputBuffer.length);
                        }
                        bytesRead = 0;
                        endOfFile = true;
                    }
                    else
                    {
                    	outputStream.write(inputBuffer, 0, bytesRead);
                    }

                } while (bytesRead != 0);

            } while (!endOfFile);

        	enviarConfirmacion();
            
            outputStream.close();

        }
        catch (Exception e)
        {
        	addText("Error en la lectura del fichero " + fichero + "\r\n\r\n");
            throw e;
        }


        try
        {
        	copy ("archivo.txt", fichero);
        	File dir = getFilesDir(); 
        	File file = new File(dir, "archivo.txt"); 
        	file.delete(); 
        }
        catch (Exception e)
        {
        	addText("Error en la escritura del fichero " + fichero + "\r\n\r\n");
            throw e;
        }

    }
	
    private void copy (String origen, String destino) throws IOException
    {	
    	try{
    		InputStream  inStream  = openFileInput(origen);
    		OutputStream outStream = openFileOutput(destino, Context.MODE_PRIVATE);
 
    	    byte[] buffer = new byte[1024];
 
    	    int length;
    	    //copy the file content in bytes 
    	    while ((length = inStream.read(buffer)) > 0){
    	    	outStream.write(buffer, 0, length);
    	    }
 
    	    inStream.close();
    	    outStream.close();
 
    	}catch(IOException e){
    		throw e;
    	}
    }

    private void setText(final String mensaje)
    {
    	textView.post(new Runnable() {
            public void run() {
            	textView.setText(mensaje);
            }    
    	});
    }
    
    private void addText(final String mensaje)
    {
    	textView.post(new Runnable() {
            public void run() {
            	textView.setText(textView.getText() + mensaje);
            }    
    	});
    }
    
    private void setTextColor(final int color)
    {
    	textView.post(new Runnable() {
            public void run() {
            	textView.setTextColor(color);
            }    
    	});
    }
    
    private void setTextSize(final int size)
    {
    	textView.post(new Runnable() {
            public void run() {
            	textView.setTextSize(size);
            }    
    	});
    }
        
    /** 
     * Actualiza la base de datos Ventas desde un fichero de texto. Cada lnea del fichero
     * comenzar por I, D, U, seguido del nombre de la tabla sobre la que se realiza la
     * operacin:
	 *		- I: Contendr las sentencia INSERT que se debern realizar en la 
	 *                    tabla de destino.
	 *		- D: Contendr las sentencias DELETE que se debern realizar en la 
	 *                    tabla de destino.
	 *      - U: Contendr las sentencias UPDATE que se debern realizar en la
	 *                    tabla de destino.
     *  
     * @param fichero  		Fichero de texto origen
     * @param limpiaDB  	Eliminar previamente el contenido de la base de datos
     * @return true if the note was successfully updated, false otherwise 
     */ 
	private boolean actualizaVentas(String fichero, boolean limpiaDB){
    	actualizandoVentas  = true;
    	//DBAdapter dbHelper = new DBAdapter(this);
    	int contador        = 1;
/*    	
    	try{
    		dbHelper.open();
    	}
   	    catch (Exception e){
   	    	actualizandoVentas = false;
   	    	return false;
   	    }
*/    	
    	//Limpiar la base de datos.
    	if (limpiaDB)
    		//dbHelper.limpiaVentas();
    		mDbHelper.limpiaVentas();
    	
       	try{
        	String systemdir   = getFilesDir().getAbsolutePath();
        	
	    	BufferedReader buf = new BufferedReader(new FileReader(systemdir + "/" + fichero));
	    	String str = null;
	    		    	
	    	while ((str = buf.readLine()) != null) {
	    		//Vamos a prevenir que el fichero de texto venga en formato UTF-8 en lugar de ASCII; en UTF-8
	    		//los tres primeros caracteres son de inicio de fichero y no se los come el ASCII.
	        	if (str.length() > 3) {
	        		//Cada lnea de este fechero debe comenzar por I:Insert; U:Update; D:Delete.
	        		if ((!str.substring(0, 1).equalsIgnoreCase("I")) && (!str.substring(0, 1).equalsIgnoreCase("U")) && (!str.substring(0, 1).equalsIgnoreCase("D"))){
	        			str = str.substring(1);
	        			if ((!str.substring(0, 1).equalsIgnoreCase("I")) && (!str.substring(0, 1).equalsIgnoreCase("U")) && (!str.substring(0, 1).equalsIgnoreCase("D"))){ 
		        			str = str.substring(1);
		        			if ((!str.substring(0, 1).equalsIgnoreCase("I")) && (!str.substring(0, 1).equalsIgnoreCase("U")) && (!str.substring(0, 1).equalsIgnoreCase("D")))
			        			str = str.substring(1);
		        		}
	        		}
	        	}

	        	//dbHelper.procesaLineaTexto(str);
	        	mDbHelper.procesaLineaTexto(str);
	    		this.setText("Actualizando registro " + contador);
	    		contador++;
	    	}
	    	
	    	//dbHelper.close();
	    	buf.close();
        	File dir = getFilesDir(); 
        	File file = new File(dir, fichero); 
        	file.delete(); 
    	}    	
	    catch (Exception e){
	    	actualizandoVentas = false;
	    	this.addText("\r\n\r\n\r\n" + e.getMessage());
	    	//dbHelper.close();
	    	return false;
	    }
	    
       	actualizandoVentas = false;
    	return true;
    }
    
    private void datosConfig(){ 	
    	Cursor curConfig = mDbHelper.getConfig();
    	if (curConfig.getCount() > 0) {
            ip_destino   = curConfig.getString(curConfig.getColumnIndexOrThrow(ConfigDBAdapter.IP_DESTINO));   	 //Nombre del servidor
            nom_terminal = curConfig.getString(curConfig.getColumnIndexOrThrow(ConfigDBAdapter.NOM_TERMINAL));	 //Nombre del terminal
            id_terminal  = curConfig.getInt(curConfig.getColumnIndexOrThrow(ConfigDBAdapter.ID_TERMINAL));       //Identificacin del terminal
    	}
    	else {
    		getIpDestino();
    		
    	}
    	puerto       = 14200;                    //Puerto base para conectarnos

    }
    
    private void setConfig(){
    	if (ip_destino.length() > 0 &&  
    		nom_terminal.length() == 5 &&
    		nom_terminal.substring(0, 2).equalsIgnoreCase("TC")) {
    		
    		id_terminal = Integer.valueOf(nom_terminal.substring(2));
    		mDbHelper.createConfig(ip_destino, nom_terminal, id_terminal, 1);
    		
    	}
    	else {
    		msgBox("Parametros incorrectos", "Error", true);
    	}
    }
    
    private void getIpDestino(){
    	LayoutInflater factory = LayoutInflater.from(this);
        final View dialoglayout = factory.inflate(R.layout.dialogo, null);
        
		AlertDialog.Builder msgbox = new AlertDialog.Builder(this);

		msgbox.setView(dialoglayout)
				.setIcon(android.R.drawable.ic_input_get)
				.setCancelable(false)
				.setTitle("DATOS CONFIGURACION")
				
				.setMessage("IP de destino:")
				.setPositiveButton("Aceptar", new OnClickListener(){

					public void onClick(DialogInterface dialog, int which) {
						// TODO Auto-generated method stub
						EditText input = (EditText) dialoglayout.findViewById(R.id.dg_editText);
						ip_destino = input.getText().toString();
						getNomTerminal();
					}
					 
				})
				.setNegativeButton("Cancelar", new OnClickListener(){

					public void onClick(DialogInterface dialog, int which) {
						// TODO Auto-generated method stub
						finish();
					}
					
				});
		
		TextView text = (TextView) dialoglayout.findViewById(R.id.dg_textView);
		text.setSingleLine(true);
		text.setVisibility(View.VISIBLE);
		text.setTextColor(MainActivity.COLOR_AZUL);
		text.setGravity(Gravity.CENTER);
		text.setText("###.###.###.###");
		
		final EditText edit = (EditText) dialoglayout.findViewById(R.id.dg_editText);
        InputFilter[] filters = new InputFilter[1];
        filters[0] = new InputFilter() {

			public CharSequence filter(CharSequence source, int start, int end,
					Spanned dest, int dstart, int dend) {
				// TODO Auto-generated method stub
				 if (end > start) {
                     String destTxt = dest.toString();
                     String resultingTxt = destTxt.substring(0, dstart) +
                     source.subSequence(start, end) +
                     destTxt.substring(dend);
                     if (!resultingTxt.matches ("^\\d{1,3}(\\.(\\d{1,3}(\\.(\\d{1,3}(\\.(\\d{1,3})?)?)?)?)?)?")) { 
                         return "";
                     } 
                     else {
                         String[] splits = resultingTxt.split("\\.");
                         for (int i=0; i<splits.length; i++) {
                             if (Integer.valueOf(splits[i]) > 255) {
                                 return "";
                             }
                         }
                     }
                 }
				return null;
			}        
		};
        edit.setFilters(filters);
		edit.setHint("IP de destino");
		edit.setSingleLine(true);
		edit.setVisibility(View.VISIBLE);
		edit.setInputType(InputType.TYPE_NUMBER_FLAG_DECIMAL);
		
		msgbox.show();
    }
    
    private void getNomTerminal(){
    	LayoutInflater factory = LayoutInflater.from(this);
        final View dialoglayout = factory.inflate(R.layout.dialogo, null);
    	
		AlertDialog.Builder msgbox = new AlertDialog.Builder(this);
        
        TelephonyManager telephonyManager = (TelephonyManager) getSystemService(Context.TELEPHONY_SERVICE);
        uid = telephonyManager.getDeviceId();
        
		msgbox.setView(dialoglayout)
				.setIcon(android.R.drawable.ic_input_get)
				.setCancelable(false)
				//.setTitle("Introduce:")
				.setTitle("dispositivo:\n" + uid)
				
				//.setMessage("Introduce Nombre de Terminal:")
				.setMessage("Nombre de Terminal:")
				.setPositiveButton("Aceptar", new OnClickListener(){

					public void onClick(DialogInterface dialog, int which) {
						// TODO Auto-generated method stub
						EditText input = (EditText) dialoglayout.findViewById(R.id.dg_editText);
						nom_terminal = input.getText().toString();
						setConfig();
						//getIdEmpresa();
					}
					
				})
				.setNegativeButton("Cancelar", new OnClickListener(){

					public void onClick(DialogInterface dialog, int which) {
						// TODO Auto-generated method stub
						finish();
					}
					
				});
		 
		TextView text = (TextView) dialoglayout.findViewById(R.id.dg_textView);
		text.setSingleLine(false);
		text.setVisibility(View.VISIBLE);
		text.setTextColor(MainActivity.COLOR_AZUL);
		text.setText("Debe comenzar con TC\n" +
					 "y continuar con tres digitos numericos");
		EditText edit = (EditText) dialoglayout.findViewById(R.id.dg_editText);
		edit.setSingleLine(true);
		edit.setVisibility(View.VISIBLE);
		edit.setInputType(InputType.TYPE_TEXT_FLAG_CAP_CHARACTERS);
		edit.setText("TC000");
		edit.setSelection(2,5);
		
		msgbox.show();
    }
    
    
    public void msgBox(String str, String titulo, boolean fin) { 
        AlertDialog.Builder dlgAlert  = new AlertDialog.Builder(this);                       
        dlgAlert.setMessage(str);  
        dlgAlert.setTitle(titulo);
        if (fin) {
	        dlgAlert.setPositiveButton("Aceptar",new DialogInterface.OnClickListener() { 
	            public void onClick(DialogInterface dialog, int whichButton) {
	                finish();  
	            } 
	        }); 
        }
        else {
            dlgAlert.setPositiveButton("Aceptar",null); 
        }
        dlgAlert.setCancelable(true); 
        dlgAlert.create().show(); 
    } 
    
     //ESTA PARTE ES SOLO PARA LA IMPORTACION LOCAL A MODO DEMO
    private void importacionCompletaLocal() {
    	
        try {

            //PASO SIETE: 	Traerse el fichero trascomp.txt
            addText("Importando Base de Datos.\r\n\r\n");
            copyAssets(FICHERO_IMPORTACION_COMPLETA);
            
			//PASO NUEVE: 	Cerramos los puertos.
	        cerrarPuertos();
	        
            //PASO ONCE: Actualizamos la base de datos de ventas.
            if (!actualizaVentas(FICHERO_IMPORTACION_COMPLETA, true)){
    	    	setTextColor(Color.RED);
    	    	addText("Error al actualizar la base de datos local");
    			return;
            }
        } catch (Exception e) {
	    	setTextColor(Color.RED);
	    	addText("Error en la transmisin de datos.");
	        cerrarPuertos();
			return;
		}  

        
    	setTextColor(Color.BLUE);
    	setTextSize(20);
      	setText("IMPORTACIN COMPLETA FINALIZADA");
    }
    
    
	
	private void copyAssets(String file) {
	    AssetManager assetManager = getAssets();
	
	    String systemdir   = getFilesDir().getAbsolutePath();
	    
	        InputStream in = null;
	        OutputStream out = null;
	        try {
	          in = assetManager.open(file);
	          out = new FileOutputStream(systemdir + "/" + file);
	          copyFile(in, out);
	          in.close();
	          in = null;
	          out.flush();
	          out.close();
	          out = null;
	        } catch(IOException e) {
	            Log.e("tag", "Failed to copy asset file: " + file, e);
	        }       
	
	}
	private void copyFile(InputStream in, OutputStream out) throws IOException {
	    byte[] buffer = new byte[1024];
	    int read;
	    while((read = in.read(buffer)) != -1){
	      out.write(buffer, 0, read);
	    }
	}
    
}
